@@ -116,7 +116,6 @@ CCDSim::CCDSim()
     raPE=RA;
     decPE=Dec;
 
-    //  sxvh9
     bias=1500;
     maxnoise=20;
     maxval=65000;
@@ -124,14 +123,14 @@ CCDSim::CCDSim()
     minpix =65000;
     limitingmag=11.5;
     saturationmag=2;
-    focallength=1280;   //  focal length of the telescope in millimeters
-    guider_focallength=1280;
+    FocalLength=1280;   //  focal length of the telescope in millimeters
     OAGoffset=0;    //  An oag is offset this much from center of scope position (arcminutes);
     skyglow=40;
 
     seeing=3.5;         //  fwhm of our stars
     ImageScalex=1.0;    //  preset with a valid non-zero
     ImageScaley=1.0;
+    rotationCW = 0;
     time(&RunStart);
 
     //  Our PEPeriod is 8 minutes
@@ -171,6 +170,7 @@ bool CCDSim::SetupParms()
     OAGoffset=SimulatorSettingsN[10].value;    //  An oag is offset this much from center of scope position (arcminutes);
     polarError=SimulatorSettingsN[11].value;
     polarDrift=SimulatorSettingsN[12].value;
+    rotationCW=SimulatorSettingsN[13].value;
 
     nbuf = PrimaryCCD.getXRes() * PrimaryCCD.getYRes() * PrimaryCCD.getBPP()/8;
     nbuf += 512;
@@ -219,7 +219,8 @@ bool CCDSim::initProperties()
     IUFillNumber(&SimulatorSettingsN[10],"SIM_OAGOFFSET","Oag Offset (arcminutes)","%4.1f",0,6000,0,0);
     IUFillNumber(&SimulatorSettingsN[11],"SIM_POLAR","PAE (arcminutes)","%4.1f",-600,600,0,0); /* PAE = Polar Alignment Error */
     IUFillNumber(&SimulatorSettingsN[12],"SIM_POLARDRIFT","PAE Drift (minutes)","%4.1f",0,6000,0,0);
-    IUFillNumberVector(SimulatorSettingsNV,SimulatorSettingsN,13,getDeviceName(),"SIMULATOR_SETTINGS","Simulator Settings","Simulator Config",IP_RW,60,IPS_IDLE);
+    IUFillNumber(&SimulatorSettingsN[13],"SIM_ROTATION","Rotation CW (degrees)","%4.1f",-360,360,0,0);
+    IUFillNumberVector(SimulatorSettingsNV,SimulatorSettingsN,14,getDeviceName(),"SIMULATOR_SETTINGS","Simulator Settings","Simulator Config",IP_RW,60,IPS_IDLE);
 
     IUFillSwitch(&TimeFactorS[0],"1X","Actual Time",ISS_ON);
     IUFillSwitch(&TimeFactorS[1],"10X","10x",ISS_OFF);
@@ -229,12 +230,6 @@ bool CCDSim::initProperties()
     IUFillNumber(&FWHMN[0],"SIM_FWHM","FWHM (arcseconds)","%4.2f",0,60,0,7.5);
     IUFillNumberVector(&FWHMNP,FWHMN,1,ActiveDeviceT[1].text, "FWHM","FWHM",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
 
-    IUFillNumber(&ScopeParametersN[0],"TELESCOPE_APERTURE","Aperture (mm)","%g",50,4000,0,0.0);
-    IUFillNumber(&ScopeParametersN[1],"TELESCOPE_FOCAL_LENGTH","Focal Length (mm)","%g",100,10000,0,0.0 );
-    IUFillNumber(&ScopeParametersN[2],"GUIDER_APERTURE","Guider Aperture (mm)","%g",50,4000,0,0.0);
-    IUFillNumber(&ScopeParametersN[3],"GUIDER_FOCAL_LENGTH","Guider Focal Length (mm)","%g",100,10000,0,0.0 );
-    IUFillNumberVector(&ScopeParametersNP,ScopeParametersN,4,ActiveDeviceT[0].text,"TELESCOPE_INFO","Scope Properties",OPTIONS_TAB,IP_RW,60,IPS_OK);
-
     IUFillSwitch(&CoolerS[0], "COOLER_ON", "ON", ISS_OFF);
     IUFillSwitch(&CoolerS[1], "COOLER_OFF", "OFF", ISS_ON);
     IUFillSwitchVector(&CoolerSP, CoolerS, 2, getDeviceName(), "CCD_COOLER", "Cooler", MAIN_CONTROL_TAB, IP_WO, ISR_1OFMANY, 0, IPS_IDLE);
@@ -244,7 +239,6 @@ bool CCDSim::initProperties()
     IUFillNumberVector(&EqPENP,EqPEN,2,ActiveDeviceT[0].text,"EQUATORIAL_PE","EQ PE","Main Control",IP_RW,60,IPS_IDLE);
 
     IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_PE");
-    IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
     IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");       
 
     initFilterProperties(getDeviceName(), FILTER_TAB);
@@ -513,15 +507,11 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
     ptr=(unsigned short int *) targetChip->getFrameBuffer();
 
     if (targetChip->getXRes() == 500)
-    {
-        targetFocalLength = guider_focallength;
         ExposureTime = GuideExposureRequest;
-    }
     else
-    {
-        targetFocalLength = focallength;
         ExposureTime = ExposureRequest;
-    }
+
+    targetFocalLength = FocalLength;
 
     if(ShowStarField)
     {
@@ -568,38 +558,42 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         //  the standard co-ordinates on each star for drawing
         //  a ccd frame;
         double pa,pb,pc,pd,pe,pf;
-        //  Since this is a simple ccd, correctly aligned
-        //  for now we cheat
-        //  no offset or rotation for and y axis means
-        pb=0.0;
+        // Pixels per radian
+        double pprx, ppry;
+        // Scale in arcsecs per pixel
+        double Scalex;
+        double Scaley;
+
+        // Pixels per radian
+        pprx = targetFocalLength/targetChip->getPixelSizeX()*1000/targetChip->getBinX();
+        ppry = targetFocalLength/targetChip->getPixelSizeY()*1000/targetChip->getBinY();
+
+        //  we do a simple scale for x and y locations
+        //  based on the focal length and pixel size
+        //  focal length in mm, pixels in microns
+        // JM: 2015-03-17: Using a simpler formula, Scalex and Scaley are in arcsecs/pixel
+        Scalex=(targetChip->getPixelSizeX() / targetFocalLength) * 206.3 * targetChip->getBinX();
+        Scaley=(targetChip->getPixelSizeY() / targetFocalLength) * 206.3 * targetChip->getBinY();
+
+        double theta = rotationCW + 180;
+        if (theta > 360)
+            theta -=360;
+        else if (theta < -360)
+            theta += 360;
+
+        // JM: 2015-03-17: Next we do a rotation assuming CW for angle theta
+        pa=pprx*cos(theta*M_PI/180.0);
+        pb=ppry*sin(theta*M_PI/180.0);
+
+        pd=pprx*-sin(theta*M_PI/180.0);
+        pe=ppry*cos(theta*M_PI/180.0);
+
         nwidth = targetChip->getXRes() / targetChip->getBinX();
-        pc=nwidth/2;
-        pd=0.0;
+        pc=nwidth/2;        
 
         nheight = targetChip->getYRes() / targetChip->getBinY();
         pf=nheight/2;
-        //  and we do a simple scale for x and y locations
-        //  based on the focal length and pixel size
-        //  focal length in mm, pixels in microns
-        pa=targetFocalLength/targetChip->getPixelSizeX()*1000/targetChip->getBinX();
-        pe=targetFocalLength/targetChip->getPixelSizeY()*1000/targetChip->getBinY();
 
-        //IDLog("Focal length is %6.4f Pixels are %4.2f %4.2f  pa %6.4f  pe %6.4f\n",targetFocalLength,
-	//      targetChip->getPixelSizeX(), targetChip->getPixelSizeY(),pa,pe);
-
-        //  these numbers are now pixels per radian
-        float Scalex;
-        float Scaley;
-        Scalex=pa*0.0174532925;    //  pixels per degree
-        Scalex=Scalex/3600.0;           // pixels per arcsecond
-        Scalex=1.0/Scalex;  //  arcseconds per pixel
-
-        Scaley=pe*0.0174532925;    //  pixels per degree
-        Scaley=Scaley/3600.0;           // pixels per arcsecond
-        Scaley=1.0/Scaley;  //  arcseconds per pixel
-        //qq=qq/3600; //  arcseconds per pixel
-
-        //IDLog("Pixel scale is %4.2f x %4.2f\n",Scalex,Scaley);
         ImageScalex=Scalex;
         ImageScaley=Scaley;
 
@@ -976,7 +970,7 @@ int CCDSim::AddToPixel(CCDChip *targetChip, int x,int y,int val)
     return drew;
 }
 
-bool CCDSim::GuideNorth(float v)
+IPState CCDSim::GuideNorth(float v)
 {
     float c;
 
@@ -984,9 +978,10 @@ bool CCDSim::GuideNorth(float v)
     c=c/3600;
     decPE=decPE+c;
 
-    return true;
+    return IPS_OK;
 }
-bool CCDSim::GuideSouth(float v)
+
+IPState CCDSim::GuideSouth(float v)
 {
     float c;
 
@@ -994,10 +989,10 @@ bool CCDSim::GuideSouth(float v)
     c=c/3600;
     decPE=decPE-c;
 
-    return true;
+    return IPS_OK;
 }
 
-bool CCDSim::GuideEast(float v)
+IPState CCDSim::GuideEast(float v)
 {
     float c;
 
@@ -1006,9 +1001,10 @@ bool CCDSim::GuideEast(float v)
     c=c/(cos(decPE*0.0174532925));
     raPE=raPE+c;
 
-    return true;
+    return IPS_OK;
 }
-bool CCDSim::GuideWest(float v)
+
+IPState CCDSim::GuideWest(float v)
 {
     float c;
 
@@ -1017,7 +1013,7 @@ bool CCDSim::GuideWest(float v)
     c=c/(cos(decPE*0.0174532925));
     raPE=raPE-c;
 
-    return true;
+    return IPS_OK;
 }
 
 bool CCDSim::ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int n)
@@ -1132,11 +1128,9 @@ bool CCDSim::ISNewSwitch (const char *dev, const char *name, ISState *states, ch
 void CCDSim::activeDevicesUpdated()
 {
     IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_PE");
-    IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
     IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");
 
     strncpy(EqPENP.device, ActiveDeviceT[0].text, MAXINDIDEVICE);
-    strncpy(ScopeParametersNP.device, ActiveDeviceT[0].text, MAXINDIDEVICE);
     strncpy(FWHMNP.device, ActiveDeviceT[1].text, MAXINDIDEVICE);
 }
 
@@ -1149,19 +1143,7 @@ bool CCDSim::ISSnoopDevice (XMLEle *root)
            if (isDebug())
                 IDLog("CCD Simulator: New FWHM value of %g\n", seeing);
            return true;
-     }
-
-     if (IUSnoopNumber(root,&ScopeParametersNP)==0)
-     {
-           focallength = ScopeParametersNP.np[1].value;
-           guider_focallength = ScopeParametersNP.np[3].value;
-           if (isDebug())
-           {
-                IDLog("CCD Simulator: New focalLength value of %g\n", focallength);
-                IDLog("CCD Simulator: New guider_focalLength value of %g\n", guider_focallength);
-           }
-           return true;
-     }
+     }     
 
      // We try to snoop EQPEC first, if not found, we snoop regular EQNP
      if(IUSnoopNumber(root,&EqPENP)==0)
