@@ -58,10 +58,10 @@ public:
     int DrawImageStar(CCDChip *targetChip, float,float,float);
     int AddToPixel(CCDChip *targetChip, int,int,int);
 
-    bool GuideNorth(float);
-    bool GuideSouth(float);
-    bool GuideEast(float);
-    bool GuideWest(float);
+    IPState GuideNorth(float);
+    IPState GuideSouth(float);
+    IPState GuideEast(float);
+    IPState GuideWest(float);
 
     virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
     virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
@@ -99,9 +99,8 @@ public:
         float seeing;
         float ImageScalex;
         float ImageScaley;
-        float focallength;
-        float guider_focallength;
         float OAGoffset;
+        float rotationCW;
         float TimeFactor;
         //  our zero point calcs used for drawing stars
         float k;
@@ -126,7 +125,7 @@ public:
         //  And this lives in our simulator settings page
 
         INumberVectorProperty *SimulatorSettingsNV;
-        INumber SimulatorSettingsN[13];
+        INumber SimulatorSettingsN[14];
 
         ISwitch TimeFactorS[3];
         ISwitchVectorProperty *TimeFactorSV;
@@ -138,8 +137,8 @@ public:
         INumber FWHMN[1];
 
         // We are going to snoop these from telescope
-        INumber ScopeParametersN[4];
-        INumberVectorProperty ScopeParametersNP;
+        //INumber ScopeParametersN[4];
+        //INumberVectorProperty ScopeParametersNP;
 
         INumberVectorProperty EqPENP;
         INumber EqPEN[2];
