@@ -39,10 +39,8 @@ class LX200AstroPhysics : public LX200Generic
   LX200AstroPhysics();
   ~LX200AstroPhysics() {}
 
-
- virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
- virtual bool ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n);
  virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
+ virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
  virtual void ISGetProperties(const char *dev);
 
  void setupTelescope();
@@ -57,19 +55,26 @@ protected:
 
  virtual bool ReadScopeStatus();
 
+ // Parking
+ virtual void SetCurrentPark();
+ virtual void SetDefaultPark();
  virtual bool Park();
+ virtual bool UnPark();
+
  virtual bool Sync(double ra, double dec);
  virtual bool Goto(double, double);
- virtual bool Connect(char *);
+ virtual bool Connect(const char *port, uint16_t baud);
  virtual bool Disconnect();
  virtual bool updateTime(ln_date * utc, double utc_offset);
  virtual bool updateLocation(double latitude, double longitude, double elevation);
+ virtual bool SetSlewRate(int index);
 
  virtual void debugTriggered(bool enable);
- virtual void processButton(const char * button_n, ISState state);
  bool  setBasicDataPart0();
  bool  setBasicDataPart1();
 
+ unsigned int DBG_SCOPE;
+
  ISwitch StartUpS[2];
  ISwitchVectorProperty StartUpSP;
 
@@ -79,11 +84,8 @@ protected:
  INumber HorizontalCoordsN[2];
  INumberVectorProperty HorizontalCoordsNP;
 
- ISwitch MoveToRateS[4];
- ISwitchVectorProperty MoveToRateSP;
-
- ISwitch SlewRateS[3];
- ISwitchVectorProperty SlewRateSP;
+ ISwitch SlewSpeedS[3];
+ ISwitchVectorProperty SlewSpeedSP;
 
  ISwitch SwapS[2];
  ISwitchVectorProperty SwapSP;
@@ -97,8 +99,11 @@ protected:
  IText   DeclinationAxisT[1];
  ITextVectorProperty DeclinationAxisTP;
 
- INumber APSiderealTimeN[1];
- INumberVectorProperty APSiderealTimeNP;
+ //INumber APSiderealTimeN[1];
+ //INumberVectorProperty APSiderealTimeNP;
+
+ INumber SlewAccuracyN[2];
+ INumberVectorProperty SlewAccuracyNP;
 
  bool timeUpdated, locationUpdated;
 
