@@ -39,6 +39,8 @@
 #include "lx200_16.h"
 #include "lx200classic.h"
 #include "lx200ap.h"
+#include "lx200gemini.h"
+#include "lx200fs2.h"
 
 // We declare an auto pointer to LX200Generic.
 std::auto_ptr<LX200Generic> telescope(0);
@@ -106,6 +108,20 @@ void ISInit()
 
     if(telescope.get() == 0) telescope.reset(new LX200AstroPhysics());
 
+ }
+ else if (strstr(me, "indi_lx200gemini"))
+ {
+      IDLog("initializing from Losmandy Gemini device...\n");
+
+      if(telescope.get() == 0) telescope.reset(new LX200Gemini());
+
+ }
+ else if (strstr(me, "indi_lx200fs2"))
+ {
+       IDLog("initializing from Astro-Electronic FS-2...\n");
+
+       if(telescope.get() == 0) telescope.reset(new LX200FS2());
+
  }
  // be nice and give them a generic device
  else
@@ -163,32 +179,37 @@ LX200Generic::LX200Generic()
    setVersion(2, 0);
 
    currentSiteNum = 1;
-   trackingMode   = LX200_TRACK_DEFAULT;
+   trackingMode   = LX200_TRACK_SIDEREAL;
    GuideNSTID     = 0;
    GuideWETID     = 0;
 
-   controller = new INDI::Controller(this);   
-   controller->setJoystickCallback(joystickHelper);
-   controller->setButtonCallback(buttonHelper);
+   DBG_SCOPE = INDI::Logger::getInstance().addDebugLevel("Scope Verbose", "SCOPE");
+
+   currentRA=ln_get_apparent_sidereal_time(ln_get_julian_from_sys());
+   currentDEC=90;
 
    TelescopeCapability cap;
 
    cap.canPark = true;
    cap.canSync = true;
    cap.canAbort = true;
+   cap.hasTime = true;
+   cap.hasLocation = true;
+   cap.nSlewRate=4;
    SetTelescopeCapability(&cap);
 
-   IDLog("Initializing from generic LX200 device...\n");   
+   DEBUG(INDI::Logger::DBG_DEBUG, "Initializing from Generic LX200 device...");
 }
 
 LX200Generic::~LX200Generic()
 { 
-    delete(controller);
+
 }
 
 void LX200Generic::debugTriggered(bool enable)
 {
-   setLX200Debug(enable ? 1 : 0);
+   INDI_UNUSED(enable);
+   setLX200Debug(getDeviceName(), DBG_SCOPE);
 }
 
 const char * LX200Generic::getDefaultName()
@@ -206,16 +227,17 @@ bool LX200Generic::initProperties()
     IUFillSwitch(&AlignmentS[2], "Land", "", ISS_OFF);
     IUFillSwitchVector(&AlignmentSP, AlignmentS, 3, getDeviceName(), "Alignment", "", MAIN_CONTROL_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
 
-    IUFillSwitch(&SlewModeS[0], "Max", "", ISS_ON);
-    IUFillSwitch(&SlewModeS[1], "Find", "", ISS_OFF);
-    IUFillSwitch(&SlewModeS[2], "Centering", "", ISS_OFF);
-    IUFillSwitch(&SlewModeS[3], "Guide", "", ISS_OFF);
-    IUFillSwitchVector(&SlewModeSP, SlewModeS, 4, getDeviceName(), "Slew Rate", "", MOTION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+    IUFillSwitch(&SlewRateS[SLEW_GUIDE], "SLEW_GUIDE", "Guide", ISS_OFF);
+    IUFillSwitch(&SlewRateS[SLEW_CENTERING], "SLEW_CENTERING", "Centering", ISS_OFF);
+    IUFillSwitch(&SlewRateS[SLEW_FIND], "SLEW_FIND", "Find", ISS_OFF);
+    IUFillSwitch(&SlewRateS[SLEW_MAX], "SLEW_MAX", "Max", ISS_ON);
+    IUFillSwitchVector(&SlewRateSP, SlewRateS, 4, getDeviceName(), "TELESCOPE_SLEW_RATE", "Slew Rate", MOTION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
 
-    IUFillSwitch(&TrackModeS[0], "Default", "", ISS_ON);
-    IUFillSwitch(&TrackModeS[1], "Lunar", "", ISS_OFF);
-    IUFillSwitch(&TrackModeS[2], "Manual", "", ISS_OFF);
-    IUFillSwitchVector(&TrackModeSP, TrackModeS, 3, getDeviceName(), "Tracking Mode", "", MOTION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+    IUFillSwitch(&TrackModeS[0], "TRACK_SIDEREAL", "Sidereal", ISS_ON);
+    IUFillSwitch(&TrackModeS[1], "TRACK_SOLAR", "Solar", ISS_OFF);
+    IUFillSwitch(&TrackModeS[2], "TRACK_LUNAR", "Lunar", ISS_OFF);
+    IUFillSwitch(&TrackModeS[3], "TRACK_CUSTOM", "Custom", ISS_OFF);
+    IUFillSwitchVector(&TrackModeSP, TrackModeS, 4, getDeviceName(), "TELESCOPE_TRACK_RATE", "Tracking Mode", MOTION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
 
     IUFillNumber(&TrackFreqN[0], "trackFreq", "Freq", "%g", 56.4,60.1, 0.1, 60.1);
     IUFillNumberVector(&TrackingFreqNP, TrackFreqN, 1, getDeviceName(), "Tracking Frequency", "", MOTION_TAB, IP_RW, 0, IPS_IDLE);
@@ -233,7 +255,6 @@ bool LX200Generic::initProperties()
     IUFillText(&SiteNameT[0], "Name", "", "");
     IUFillTextVector(&SiteNameTP, SiteNameT, 1, getDeviceName(), "Site Name", "", SITE_TAB, IP_RW, 0, IPS_IDLE);
 
-
     IUFillSwitch(&FocusMotionS[0], "IN", "Focus in", ISS_OFF);
     IUFillSwitch(&FocusMotionS[1], "OUT", "Focus out", ISS_OFF);
     IUFillSwitchVector(&FocusMotionSP, FocusMotionS, 2, getDeviceName(), "FOCUS_MOTION", "Motion", FOCUS_TAB, IP_RW, ISR_ATMOST1, 0, IPS_IDLE);
@@ -246,15 +267,6 @@ bool LX200Generic::initProperties()
     IUFillSwitch(&FocusModeS[2], "FOCUS_FAST", "Fast", ISS_OFF);
     IUFillSwitchVector(&FocusModeSP, FocusModeS, 3, getDeviceName(), "FOCUS_MODE", "Mode", FOCUS_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
 
-    controller->mapController("NSWE Control", "NSWE Control", INDI::Controller::CONTROLLER_JOYSTICK, "JOYSTICK_1");
-    controller->mapController("Slew Max", "Slew Max", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_1");
-    controller->mapController("Slew Find", "Slew Find", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_2");
-    controller->mapController("Slew Centering", "Slew Centering", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_3");
-    controller->mapController("Slew Guide", "Slew Guide", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_4");
-    controller->mapController("Abort Motion", "Abort Motion", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_5");
-
-    controller->initProperties();
-
     TrackState=SCOPE_IDLE;
 
     initGuiderProperties(getDeviceName(), GUIDE_TAB);
@@ -277,7 +289,6 @@ void LX200Generic::ISGetProperties(const char *dev)
     if (isConnected())
     {
         defineSwitch(&AlignmentSP);
-        defineSwitch(&SlewModeSP);
         defineSwitch(&TrackModeSP);
         defineNumber(&TrackingFreqNP);
         defineSwitch(&UsePulseCmdSP);
@@ -293,8 +304,6 @@ void LX200Generic::ISGetProperties(const char *dev)
         defineSwitch(&FocusModeSP);
     }
 
-    controller->ISGetProperties(dev);
-
 }
 
 bool LX200Generic::updateProperties()
@@ -304,7 +313,6 @@ bool LX200Generic::updateProperties()
     if (isConnected())
     {
         defineSwitch(&AlignmentSP);
-        defineSwitch(&SlewModeSP);
         defineSwitch(&TrackModeSP);
         defineNumber(&TrackingFreqNP);
         defineSwitch(&UsePulseCmdSP);
@@ -321,12 +329,11 @@ bool LX200Generic::updateProperties()
 
         getBasicData();
 
-        loadConfig(true);
+        //loadConfig(true);
     }
     else
     {
         deleteProperty(AlignmentSP.name);
-        deleteProperty(SlewModeSP.name);
         deleteProperty(TrackModeSP.name);
         deleteProperty(TrackingFreqNP.name);
         deleteProperty(UsePulseCmdSP.name);
@@ -342,8 +349,6 @@ bool LX200Generic::updateProperties()
         deleteProperty(FocusModeSP.name);
     }
 
-    controller->updateProperties();
-
     return true;
 }
 
@@ -353,7 +358,7 @@ bool LX200Generic::Connect()
 
     if(isConnected()) return true;
 
-    rc=Connect(PortT[0].text);
+    rc=Connect(PortT[0].text, atoi(IUFindOnSwitch(&BaudRateSP)->name));
 
     if(rc)
         SetTimer(POLLMS);
@@ -361,22 +366,27 @@ bool LX200Generic::Connect()
     return rc;
 }
 
-bool LX200Generic::Connect(char *port)
+bool LX200Generic::checkConnection()
+{
+    return (check_lx200_connection(PortFD) == 0);
+}
+
+bool LX200Generic::Connect(const char *port, uint16_t baud)
 {
     if (isSimulation())
     {
-        IDMessage (getDeviceName(), "Simulated LX200 is online. Retrieving basic data...");
+        DEBUGF (INDI::Logger::DBG_SESSION, "Simulated %s is online.", getDeviceName());
         return true;
     }
 
-    if (tty_connect(port, 9600, 8, 0, 1, &PortFD) != TTY_OK)
+    if (tty_connect(port, baud, 8, 0, 1, &PortFD) != TTY_OK)
     {
       DEBUGF(INDI::Logger::DBG_ERROR, "Error connecting to port %s. Make sure you have BOTH write and read permission to your port.", port);
       return false;
     }
 
 
-    if (check_lx200_connection(PortFD))
+    if (checkConnection() == false)
     {
         DEBUG(INDI::Logger::DBG_ERROR, "Error connecting to Telescope. Telescope is offline.");
         return false;
@@ -384,7 +394,7 @@ bool LX200Generic::Connect(char *port)
 
    //*((int *) UTCOffsetN[0].aux0) = 0;
 
-   IDMessage (getDeviceName(), "Telescope is online. Retrieving basic data...");
+   DEBUGF (INDI::Logger::DBG_SESSION, "%s is online. Retrieving basic data...", getDeviceName());
 
    return true;
 }
@@ -396,6 +406,11 @@ bool LX200Generic::Disconnect()
     return true;
 }
 
+bool LX200Generic::isSlewComplete()
+{
+    return ::isSlewComplete(PortFD);
+}
+
 bool LX200Generic::ReadScopeStatus()
 {
     if (isConnected() == false)
@@ -413,12 +428,12 @@ bool LX200Generic::ReadScopeStatus()
     if (TrackState == SCOPE_SLEWING)
     {
         // Check if LX200 is done slewing
-        if(isSlewComplete(PortFD) == 0)
+        if (isSlewComplete())
         {
             // Set slew mode to "Centering"
-            IUResetSwitch(&SlewModeSP);
-            SlewModeS[2].s = ISS_ON;
-            IDSetSwitch(&SlewModeSP, NULL);
+            IUResetSwitch(&SlewRateSP);
+            SlewRateS[SLEW_CENTERING].s = ISS_ON;
+            IDSetSwitch(&SlewRateSP, NULL);
 
             TrackState=SCOPE_TRACKING;
             IDMessage(getDeviceName(),"Slew is complete. Tracking...");
@@ -427,12 +442,9 @@ bool LX200Generic::ReadScopeStatus()
     }
     else if(TrackState == SCOPE_PARKING)
     {
-        if(isSlewComplete(PortFD) == 0)
+        if(isSlewComplete())
         {
-            TrackState=SCOPE_PARKED;
-            ParkSP.s=IPS_OK;
-            IDSetSwitch(&ParkSP,NULL);
-            IDMessage(getDeviceName(),"Telescope is Parked.");
+            SetParked(true);
         }
     }
 
@@ -450,6 +462,7 @@ bool LX200Generic::ReadScopeStatus()
 
 bool LX200Generic::Goto(double r,double d)
 {
+
     targetRA=r;
     targetDEC=d;
     char RAStr[64], DecStr[64];
@@ -506,7 +519,6 @@ bool LX200Generic::Goto(double r,double d)
         }
     }
 
-    //Parked=false;
     TrackState = SCOPE_SLEWING;
     EqNP.s    = IPS_BUSY;
 
@@ -518,7 +530,6 @@ bool LX200Generic::Sync(double ra, double dec)
 {
     char syncString[256];
 
-
     if (isSimulation() == false &&
             (setObjectRA(PortFD, ra) < 0 || (setObjectDEC(PortFD, dec)) < 0))
     {
@@ -537,10 +548,7 @@ bool LX200Generic::Sync(double ra, double dec)
     currentRA  = ra;
     currentDEC = dec;
 
-    if (isDebug())
-        IDLog("Synchronization successful %s\n", syncString);
-
-    IDMessage(getDeviceName(), "Synchronization successful.");
+    DEBUG(INDI::Logger::DBG_SESSION, "Synchronization successful.");
 
     TrackState = SCOPE_IDLE;
     EqNP.s    = IPS_OK;
@@ -593,16 +601,15 @@ bool LX200Generic::Park()
 
     }
 
-    ParkSP.s = IPS_OK;
-    //Parked=true;
+    ParkSP.s = IPS_BUSY;
     TrackState = SCOPE_PARKING;
     IDMessage(getDeviceName(), "Parking telescope in progress...");
     return true;
 }
 
-bool LX200Generic::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command)
+bool LX200Generic::MoveNS(INDI_DIR_NS dir, TelescopeMotionCommand command)
 {
-    int current_move = (dir == MOTION_NORTH) ? LX200_NORTH : LX200_SOUTH;
+    int current_move = (dir == DIRECTION_NORTH) ? LX200_NORTH : LX200_SOUTH;
 
     switch (command)
     {
@@ -630,10 +637,9 @@ bool LX200Generic::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command)
     return true;
 }
 
-bool LX200Generic::MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command)
+bool LX200Generic::MoveWE(INDI_DIR_WE dir, TelescopeMotionCommand command)
 {
-
-    int current_move = (dir == MOTION_WEST) ? LX200_WEST : LX200_EAST;
+    int current_move = (dir == DIRECTION_WEST) ? LX200_WEST : LX200_EAST;
 
     switch (command)
     {
@@ -705,9 +711,13 @@ bool LX200Generic::Abort()
      IDSetSwitch(&MovementNSSP, NULL);
      IDSetSwitch(&MovementWESP, NULL);
      IDSetNumber(&EqNP, NULL);
-     IUResetSwitch(&ParkSP);
-     ParkSP.s = IPS_IDLE;
-     IDSetSwitch(&ParkSP, NULL);
+
+     if (capability.canPark)
+     {
+        IUResetSwitch(&ParkSP);
+        ParkSP.s = IPS_IDLE;
+        IDSetSwitch(&ParkSP, NULL);
+     }
 
      IDMessage(getDeviceName(), "Slew aborted.");
      return true;
@@ -801,8 +811,6 @@ bool LX200Generic::ISNewText (const char *dev, const char *name, char *texts[],
 
     }
 
-    controller->ISNewText(dev, name, texts, names, n);
-
     return INDI::Telescope::ISNewText(dev, name, texts, names, n);
 }
 
@@ -832,7 +840,8 @@ bool LX200Generic::ISNewNumber (const char *dev, const char *name, double values
               trackingMode = LX200_TRACK_MANUAL;
               TrackModeS[0].s = ISS_OFF;
               TrackModeS[1].s = ISS_OFF;
-              TrackModeS[2].s = ISS_ON;
+              TrackModeS[2].s = ISS_OFF;
+              TrackModeS[3].s = ISS_ON;
               TrackModeSP.s   = IPS_OK;
               selectTrackingMode(PortFD, trackingMode);
               IDSetSwitch(&TrackModeSP, NULL);
@@ -975,28 +984,7 @@ bool LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
           FocusMotionSP.s = IPS_OK;
           IDSetSwitch(&FocusMotionSP, NULL);
           return true;
-        }
-
-        // Slew mode
-        if (!strcmp (name, SlewModeSP.name))
-        {
-
-          if (IUUpdateSwitch(&SlewModeSP, states, names, n) < 0)
-              return false;
-
-          index = IUFindOnSwitchIndex(&SlewModeSP);
-
-          if (isSimulation() == false && setSlewMode(PortFD, index) < 0)
-          {
-              SlewModeSP.s = IPS_ALERT;
-              IDSetSwitch(&SlewModeSP, "Error setting slew mode.");
-              return false;
-          }
-
-          SlewModeSP.s = IPS_OK;
-          IDSetSwitch(&SlewModeSP, NULL);
-          return true;
-        }
+        }        
 
         // Tracking mode
         if (!strcmp (name, TrackModeSP.name))
@@ -1059,13 +1047,28 @@ bool LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 
     }
 
-    controller->ISNewSwitch(dev, name, states, names, n);
-
     //  Nobody has claimed this, so pass it to the parent
     return INDI::Telescope::ISNewSwitch(dev,name,states,names,n);
 
 }
 
+bool LX200Generic::SetSlewRate(int index)
+{
+   // Convert index to Meade format
+   index = 3 - index;
+
+   if (isSimulation() == false && setSlewMode(PortFD, index) < 0)
+   {
+       SlewRateSP.s = IPS_ALERT;
+       IDSetSwitch(&SlewRateSP, "Error setting slew mode.");
+      return false;
+   }
+
+   SlewRateSP.s = IPS_OK;
+   IDSetSwitch(&SlewRateSP, NULL);
+   return true;
+}
+
 void LX200Generic::updateFocusHelper(void *p)
 {
     ((LX200Generic *) p)->updateFocusTimer();
@@ -1075,7 +1078,6 @@ void LX200Generic::updateFocusTimer()
 {
     switch (FocusTimerNP.s)
     {
-
       case IPS_IDLE:
 	   break;
 	     
@@ -1155,6 +1157,7 @@ void LX200Generic::mountSim ()
 	    break;
 
     case SCOPE_SLEWING:
+    case SCOPE_PARKING:
 	    /* slewing - nail it when both within one pulse @ SLEWRATE */
 	    nlocked = 0;
 
@@ -1182,7 +1185,13 @@ void LX200Generic::mountSim ()
 	      currentDEC -= da;
 
 	    if (nlocked == 2)
-             TrackState = SCOPE_TRACKING;
+        {
+            if (TrackState == SCOPE_SLEWING)
+                TrackState = SCOPE_TRACKING;
+            else
+                SetParked(true);
+
+        }
 
 
 	    break;
@@ -1389,7 +1398,7 @@ void LX200Generic::sendScopeLocation()
   IDSetNumber (&LocationNP, NULL);
 }
 
-bool LX200Generic::GuideNorth(float ms)
+IPState LX200Generic::GuideNorth(float ms)
 {
       int use_pulse_cmd;
 
@@ -1397,8 +1406,8 @@ bool LX200Generic::GuideNorth(float ms)
 
       if (!use_pulse_cmd && (MovementNSSP.s == IPS_BUSY || MovementWESP.s == IPS_BUSY))
       {
-        IDMessage(getDeviceName(), "Cannot guide while moving.");
-        return false;
+        DEBUG(INDI::Logger::DBG_ERROR, "Cannot guide while moving.");
+        return IPS_ALERT;
       }
 
       // If already moving (no pulse command), then stop movement
@@ -1406,7 +1415,7 @@ bool LX200Generic::GuideNorth(float ms)
       {
           int dir = IUFindOnSwitchIndex(&MovementNSSP);
 
-          MoveNS(dir == 0 ? MOTION_NORTH : MOTION_SOUTH, MOTION_STOP);
+          MoveNS(dir == 0 ? DIRECTION_NORTH : DIRECTION_SOUTH, MOTION_STOP);
 
       }
 
@@ -1423,25 +1432,25 @@ bool LX200Generic::GuideNorth(float ms)
       {
         if (setSlewMode(PortFD, LX200_SLEW_GUIDE) < 0)
         {
-            SlewModeSP.s = IPS_ALERT;
-            IDSetSwitch(&SlewModeSP, "Error setting slew mode.");
-            return false;
+            SlewRateSP.s = IPS_ALERT;
+            IDSetSwitch(&SlewRateSP, "Error setting slew mode.");
+            return IPS_ALERT;
         }
 
         MovementNSS[0].s = ISS_ON;
-        MoveNS(MOTION_NORTH, MOTION_START);
+        MoveNS(DIRECTION_NORTH, MOTION_START);
       }
 
       // Set slew to guiding
-      IUResetSwitch(&SlewModeSP);
-      SlewModeS[3].s = ISS_ON;
-      IDSetSwitch(&SlewModeSP, NULL);
+      IUResetSwitch(&SlewRateSP);
+      SlewRateS[SLEW_GUIDE].s = ISS_ON;
+      IDSetSwitch(&SlewRateSP, NULL);
       guide_direction = LX200_NORTH;
       GuideNSTID = IEAddTimer (ms, guideTimeoutHelper, this);
-      return true;
+      return IPS_BUSY;
 }
 
-bool LX200Generic::GuideSouth(float ms)
+IPState LX200Generic::GuideSouth(float ms)
 {
     int use_pulse_cmd;
 
@@ -1449,8 +1458,8 @@ bool LX200Generic::GuideSouth(float ms)
 
     if (!use_pulse_cmd && (MovementNSSP.s == IPS_BUSY || MovementWESP.s == IPS_BUSY))
     {
-      IDMessage(getDeviceName(), "Cannot guide while moving.");
-      return false;
+        DEBUG(INDI::Logger::DBG_ERROR, "Cannot guide while moving.");
+        return IPS_ALERT;
     }
 
     // If already moving (no pulse command), then stop movement
@@ -1458,7 +1467,7 @@ bool LX200Generic::GuideSouth(float ms)
     {
         int dir = IUFindOnSwitchIndex(&MovementNSSP);
 
-        MoveNS(dir == 0 ? MOTION_NORTH : MOTION_SOUTH, MOTION_STOP);
+        MoveNS(dir == 0 ? DIRECTION_NORTH : DIRECTION_SOUTH, MOTION_STOP);
 
     }
 
@@ -1475,26 +1484,26 @@ bool LX200Generic::GuideSouth(float ms)
     {
       if (setSlewMode(PortFD, LX200_SLEW_GUIDE) < 0)
       {
-          SlewModeSP.s = IPS_ALERT;
-          IDSetSwitch(&SlewModeSP, "Error setting slew mode.");
-          return false;
+          SlewRateSP.s = IPS_ALERT;
+          IDSetSwitch(&SlewRateSP, "Error setting slew mode.");
+          return IPS_ALERT;
       }
 
       MovementNSS[1].s = ISS_ON;
-      MoveNS(MOTION_SOUTH, MOTION_START);
+      MoveNS(DIRECTION_SOUTH, MOTION_START);
     }
 
     // Set slew to guiding
-    IUResetSwitch(&SlewModeSP);
-    SlewModeS[3].s = ISS_ON;
-    IDSetSwitch(&SlewModeSP, NULL);
+    IUResetSwitch(&SlewRateSP);
+    SlewRateS[SLEW_GUIDE].s = ISS_ON;
+    IDSetSwitch(&SlewRateSP, NULL);
     guide_direction = LX200_SOUTH;
     GuideNSTID = IEAddTimer (ms, guideTimeoutHelper, this);
-    return true;
+    return IPS_BUSY;
 
 }
 
-bool LX200Generic::GuideEast(float ms)
+IPState LX200Generic::GuideEast(float ms)
 {
 
     int use_pulse_cmd;
@@ -1503,8 +1512,8 @@ bool LX200Generic::GuideEast(float ms)
 
     if (!use_pulse_cmd && (MovementNSSP.s == IPS_BUSY || MovementWESP.s == IPS_BUSY))
     {
-      IDMessage(getDeviceName(), "Cannot guide while moving.");
-      return false;
+        DEBUG(INDI::Logger::DBG_ERROR, "Cannot guide while moving.");
+        return IPS_ALERT;
     }
 
     // If already moving (no pulse command), then stop movement
@@ -1512,7 +1521,7 @@ bool LX200Generic::GuideEast(float ms)
     {
         int dir = IUFindOnSwitchIndex(&MovementWESP);
 
-        MoveWE(dir == 0 ? MOTION_WEST : MOTION_EAST, MOTION_STOP);
+        MoveWE(dir == 0 ? DIRECTION_WEST : DIRECTION_EAST, MOTION_STOP);
 
     }
 
@@ -1529,26 +1538,26 @@ bool LX200Generic::GuideEast(float ms)
     {
       if (setSlewMode(PortFD, LX200_SLEW_GUIDE) < 0)
       {
-          SlewModeSP.s = IPS_ALERT;
-          IDSetSwitch(&SlewModeSP, "Error setting slew mode.");
-          return false;
+          SlewRateSP.s = IPS_ALERT;
+          IDSetSwitch(&SlewRateSP, "Error setting slew mode.");
+          return IPS_ALERT;
       }
 
       MovementWES[1].s = ISS_ON;
-      MoveWE(MOTION_EAST, MOTION_START);
+      MoveWE(DIRECTION_EAST, MOTION_START);
     }
 
     // Set slew to guiding
-    IUResetSwitch(&SlewModeSP);
-    SlewModeS[3].s = ISS_ON;
-    IDSetSwitch(&SlewModeSP, NULL);
+    IUResetSwitch(&SlewRateSP);
+    SlewRateS[SLEW_GUIDE].s = ISS_ON;
+    IDSetSwitch(&SlewRateSP, NULL);
     guide_direction = LX200_EAST;
     GuideWETID = IEAddTimer (ms, guideTimeoutHelper, this);
-    return true;
+    return IPS_BUSY;
 
 }
 
-bool LX200Generic::GuideWest(float ms)
+IPState LX200Generic::GuideWest(float ms)
 {
 
     int use_pulse_cmd;
@@ -1557,8 +1566,8 @@ bool LX200Generic::GuideWest(float ms)
 
     if (!use_pulse_cmd && (MovementNSSP.s == IPS_BUSY || MovementWESP.s == IPS_BUSY))
     {
-      IDMessage(getDeviceName(), "Cannot guide while moving.");
-      return false;
+        DEBUG(INDI::Logger::DBG_ERROR, "Cannot guide while moving.");
+        return IPS_ALERT;
     }
 
     // If already moving (no pulse command), then stop movement
@@ -1566,8 +1575,7 @@ bool LX200Generic::GuideWest(float ms)
     {
         int dir = IUFindOnSwitchIndex(&MovementWESP);
 
-        MoveWE(dir == 0 ? MOTION_WEST : MOTION_EAST, MOTION_STOP);
-
+        MoveWE(dir == 0 ? DIRECTION_WEST : DIRECTION_EAST, MOTION_STOP);
     }
 
     if (GuideWETID)
@@ -1583,22 +1591,22 @@ bool LX200Generic::GuideWest(float ms)
     {
       if (setSlewMode(PortFD, LX200_SLEW_GUIDE) < 0)
       {
-          SlewModeSP.s = IPS_ALERT;
-          IDSetSwitch(&SlewModeSP, "Error setting slew mode.");
-          return false;
+          SlewRateSP.s = IPS_ALERT;
+          IDSetSwitch(&SlewRateSP, "Error setting slew mode.");
+          return IPS_ALERT;
       }
 
       MovementWES[0].s = ISS_ON;
-      MoveWE(MOTION_WEST, MOTION_START);
+      MoveWE(DIRECTION_WEST, MOTION_START);
     }
 
     // Set slew to guiding
-    IUResetSwitch(&SlewModeSP);
-    SlewModeS[3].s = ISS_ON;
-    IDSetSwitch(&SlewModeSP, NULL);
+    IUResetSwitch(&SlewRateSP);
+    SlewRateS[SLEW_GUIDE].s = ISS_ON;
+    IDSetSwitch(&SlewRateSP, NULL);
     guide_direction = LX200_WEST;
     GuideWETID = IEAddTimer (ms, guideTimeoutHelper, this);
-    return true;
+    return IPS_BUSY;
 
 }
 
@@ -1634,7 +1642,7 @@ void LX200Generic::guideTimeout()
 
         if (guide_direction == LX200_NORTH || guide_direction == LX200_SOUTH)
         {
-            MoveNS(guide_direction == LX200_NORTH ? MOTION_NORTH : MOTION_SOUTH, MOTION_STOP);
+            MoveNS(guide_direction == LX200_NORTH ? DIRECTION_NORTH : DIRECTION_SOUTH, MOTION_STOP);
 
             if (guide_direction == LX200_NORTH)
                 GuideNSNP.np[0].value = 0;
@@ -1649,7 +1657,7 @@ void LX200Generic::guideTimeout()
         }
         if (guide_direction == LX200_WEST || guide_direction == LX200_EAST)
         {
-            MoveWE(guide_direction == LX200_WEST ? MOTION_WEST : MOTION_EAST, MOTION_STOP);
+            MoveWE(guide_direction == LX200_WEST ? DIRECTION_WEST : DIRECTION_EAST, MOTION_STOP);
             if (guide_direction == LX200_WEST)
                 GuideWENP.np[0].value = 0;
             else
@@ -1680,156 +1688,3 @@ void LX200Generic::guideTimeout()
     }
 }
 
-bool LX200Generic::ISSnoopDevice(XMLEle *root)
-{
-
-    controller->ISSnoopDevice(root);
-
-    return INDI::Telescope::ISSnoopDevice(root);
-
-}
-
-void LX200Generic::processButton(const char * button_n, ISState state)
-{
-    //ignore OFF
-    if (state == ISS_OFF)
-        return;
-
-    // Max Slew speed
-    if (!strcmp(button_n, "Slew Max"))
-    {
-        setSlewMode(PortFD, 0);
-        IUResetSwitch(&SlewModeSP);
-        SlewModeS[0].s = ISS_ON;
-        IDSetSwitch(&SlewModeSP, NULL);
-    }
-    // Find Slew speed
-    else if (!strcmp(button_n, "Slew Find"))
-    {
-            setSlewMode(PortFD, 1);
-            IUResetSwitch(&SlewModeSP);
-            SlewModeS[1].s = ISS_ON;
-            IDSetSwitch(&SlewModeSP, NULL);
-    }
-    // Centering Slew
-    else if (!strcmp(button_n, "Slew Centering"))
-    {
-            setSlewMode(PortFD, 2);
-            IUResetSwitch(&SlewModeSP);
-            SlewModeS[2].s = ISS_ON;
-            IDSetSwitch(&SlewModeSP, NULL);
-    }
-    // Guide Slew
-    else if (!strcmp(button_n, "Slew Guide"))
-    {
-            setSlewMode(PortFD, 3);
-            IUResetSwitch(&SlewModeSP);
-            SlewModeS[3].s = ISS_ON;
-            IDSetSwitch(&SlewModeSP, NULL);
-    }
-    // Abort
-    else if (!strcmp(button_n, "Abort Motion"))
-    {
-        // Only abort if we have some sort of motion going on
-        if (MovementNSSP.s == IPS_BUSY || MovementWESP.s == IPS_BUSY || EqNP.s == IPS_BUSY
-                || GuideNSNP.s == IPS_BUSY || GuideWENP.s == IPS_BUSY)
-        {
-
-            Abort();
-        }
-    }
-
-}
-
-void LX200Generic::processNSWE(double mag, double angle)
-{
-    if (mag < 0.5)
-    {
-        // Moving in the same direction will make it stop
-        if (MovementNSSP.s == IPS_BUSY || MovementWESP.s == IPS_BUSY)
-            Abort();
-    }
-    // Put high threshold
-    else if (mag > 0.9)
-    {
-        // North
-        if (angle > 0 && angle < 180)
-        {
-            // Don't try to move if you're busy and moving in the same direction
-            if (MovementNSSP.s != IPS_BUSY || MovementNSS[0].s != ISS_ON)
-                MoveNS(MOTION_NORTH, MOTION_START);
-
-            MovementNSSP.s = IPS_BUSY;
-            MovementNSSP.sp[0].s = ISS_ON;
-            MovementNSSP.sp[1].s = ISS_OFF;
-            IDSetSwitch(&MovementNSSP, NULL);
-        }
-        // South
-        if (angle > 180 && angle < 360)
-        {
-            // Don't try to move if you're busy and moving in the same direction
-           if (MovementNSSP.s != IPS_BUSY  || MovementNSS[1].s != ISS_ON)
-            MoveNS(MOTION_SOUTH, MOTION_START);
-
-            MovementNSSP.s = IPS_BUSY;
-            MovementNSSP.sp[0].s = ISS_OFF;
-            MovementNSSP.sp[1].s = ISS_ON;
-            IDSetSwitch(&MovementNSSP, NULL);
-        }
-        // East
-        if (angle < 90 || angle > 270)
-        {
-            // Don't try to move if you're busy and moving in the same direction
-           if (MovementWESP.s != IPS_BUSY  || MovementWES[1].s != ISS_ON)
-                MoveWE(MOTION_EAST, MOTION_START);
-
-           MovementWESP.s = IPS_BUSY;
-           MovementWESP.sp[0].s = ISS_OFF;
-           MovementWESP.sp[1].s = ISS_ON;
-           IDSetSwitch(&MovementWESP, NULL);
-        }
-
-        // West
-        if (angle > 90 && angle < 270)
-        {
-
-            // Don't try to move if you're busy and moving in the same direction
-           if (MovementWESP.s != IPS_BUSY  || MovementWES[0].s != ISS_ON)
-                MoveWE(MOTION_WEST, MOTION_START);
-
-           MovementWESP.s = IPS_BUSY;
-           MovementWESP.sp[0].s = ISS_ON;
-           MovementWESP.sp[1].s = ISS_OFF;
-           IDSetSwitch(&MovementWESP, NULL);
-        }
-    }
-
-}
-
-bool LX200Generic::saveConfigItems(FILE *fp)
-{    
-    controller->saveConfigItems(fp);
-
-    INDI::Telescope::saveConfigItems(fp);
-
-    return true;
-}
-
-void LX200Generic::processJoystick(const char * joystick_n, double mag, double angle)
-{
-    if (!strcmp(joystick_n, "NSWE Control"))
-        processNSWE(mag, angle);
-}
-
-
-void LX200Generic::joystickHelper(const char * joystick_n, double mag, double angle, void *context)
-{
-    static_cast<LX200Generic *>(context)->processJoystick(joystick_n, mag, angle);
-
-}
-
-void LX200Generic::buttonHelper(const char * button_n, ISState state, void *context)
-{
-    static_cast<LX200Generic *>(context)->processButton(button_n, state);
-}
-
