@@ -38,7 +38,7 @@ class LX200Generic: public INDI::Telescope, public INDI::GuiderInterface
 
     virtual const char *getDefaultName();
     virtual bool Connect();
-    virtual bool Connect(char *);
+    virtual bool Connect(const char *port, uint16_t baud);
     virtual bool Disconnect();
     virtual bool ReadScopeStatus();
     virtual void ISGetProperties(const char *dev);
@@ -47,35 +47,33 @@ class LX200Generic: public INDI::Telescope, public INDI::GuiderInterface
     virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
     virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
     virtual bool ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n);
-    virtual bool ISSnoopDevice(XMLEle *root);
 
     void updateFocusTimer();
     void guideTimeout();
 
-    static void joystickHelper(const char * joystick_n, double mag, double angle, void *context);
-    static void buttonHelper(const char * button_n, ISState state, void *context);
-
   protected:
 
-    virtual bool MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command);
-    virtual bool MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command);
+    virtual bool SetSlewRate(int index);
+    virtual bool MoveNS(INDI_DIR_NS dir, TelescopeMotionCommand command);
+    virtual bool MoveWE(INDI_DIR_WE dir, TelescopeMotionCommand command);
     virtual bool Abort();
 
     virtual bool updateTime(ln_date * utc, double utc_offset);
     virtual bool updateLocation(double latitude, double longitude, double elevation);
 
-    virtual bool GuideNorth(float ms);
-    virtual bool GuideSouth(float ms);
-    virtual bool GuideEast(float ms);
-    virtual bool GuideWest(float ms);
-
-    virtual bool saveConfigItems(FILE *fp);
+    virtual IPState GuideNorth(float ms);
+    virtual IPState GuideSouth(float ms);
+    virtual IPState GuideEast(float ms);
+    virtual IPState GuideWest(float ms);
 
     virtual bool Goto(double,double);
     virtual bool Park();
     virtual bool Sync(double ra, double dec);
 
-    virtual void debugTriggered(bool enable);
+    virtual bool isSlewComplete();
+    virtual bool checkConnection();
+
+    virtual void debugTriggered(bool enable);    
 
     virtual void getBasicData();
     void slewError(int slewCode);
@@ -87,10 +85,6 @@ class LX200Generic: public INDI::Telescope, public INDI::GuiderInterface
     static void updateFocusHelper(void *p);
     static void guideTimeoutHelper(void *p);
 
-    virtual void processNSWE(double mag, double angle);
-    virtual void processJoystick(const char * joystick_n, double mag, double angle);
-    virtual void processButton(const char * button_n, ISState state);
-
     int    GuideNSTID;
     int    GuideWETID;
 
@@ -99,24 +93,20 @@ class LX200Generic: public INDI::Telescope, public INDI::GuiderInterface
     int trackingMode;
     long guide_direction;
 
+    unsigned int DBG_SCOPE;
+
     double JD;
     double targetRA, targetDEC;
     double currentRA, currentDEC;
     int MaxReticleFlashRate;
-    INDI::Controller *controller;
-
 
   /* Telescope Alignment Mode */
   ISwitchVectorProperty AlignmentSP;
   ISwitch AlignmentS[3];
 
-  /* Slew Speed */
-  ISwitchVectorProperty SlewModeSP;
-  ISwitch SlewModeS[4];
-
   /* Tracking Mode */
   ISwitchVectorProperty TrackModeSP;
-  ISwitch TrackModeS[3];
+  ISwitch TrackModeS[4];
 
   /* Tracking Frequency */
   INumberVectorProperty TrackingFreqNP;
