@@ -97,6 +97,8 @@ SkywatcherAPIMount::SkywatcherAPIMount()
     cap.canPark = true;
     cap.canSync = true;
     cap.canAbort = true;
+    cap.hasLocation = true;
+    cap.hasTime = true;
     SetTelescopeCapability(&cap);
 }
 
@@ -266,7 +268,7 @@ bool SkywatcherAPIMount::initProperties()
     addConfigurationControl();
 
     // Add alignment properties
-    InitProperties(this);
+    InitAlignmentProperties(this);
 
     // Force the alignment system to always be on
     getSwitch("ALIGNMENT_SUBSYSTEM_ACTIVE")->sp[0].s = ISS_ON;
@@ -474,7 +476,7 @@ bool SkywatcherAPIMount::ISNewBLOB (const char *dev, const char *name, int sizes
     if(strcmp(dev,getDeviceName())==0)
     {
         // It is for us
-        ProcessBlobProperties(this, name, sizes, blobsizes, blobs, formats, names, n);
+        ProcessAlignmentBLOBProperties(this, name, sizes, blobsizes, blobs, formats, names, n);
     }
     // Pass it up the chain
     return INDI::Telescope::ISNewBLOB(dev, name, sizes, blobsizes, blobs, formats, names, n);
@@ -485,7 +487,7 @@ bool SkywatcherAPIMount::ISNewNumber (const char *dev, const char *name, double
     if(strcmp(dev,getDeviceName())==0)
     {
         // It is for us
-        ProcessNumberProperties(this, name, values, names, n);
+        ProcessAlignmentNumberProperties(this, name, values, names, n);
     }
     // Pass it up the chain
     return INDI::Telescope::ISNewNumber(dev, name, values, names, n);
@@ -496,7 +498,7 @@ bool SkywatcherAPIMount::ISNewSwitch (const char *dev, const char *name, ISState
     if(strcmp(dev,getDeviceName())==0)
     {
         // It is for us
-        ProcessSwitchProperties(this, name, states, names, n);
+        ProcessAlignmentSwitchProperties(this, name, states, names, n);
     }
     // Pass it up the chain
     return INDI::Telescope::ISNewSwitch(dev, name, states, names, n);
@@ -506,18 +508,18 @@ bool SkywatcherAPIMount::ISNewText (const char *dev, const char *name, char *tex
 {
     if(strcmp(dev,getDeviceName())==0)
     {
-        ProcessTextProperties(this, name, texts, names, n);
+        ProcessAlignmentTextProperties(this, name, texts, names, n);
     }
     // Pass it up the chain
     return INDI::Telescope::ISNewText(dev, name, texts, names, n);
 }
 
-bool SkywatcherAPIMount::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command)
+bool SkywatcherAPIMount::MoveNS(INDI_DIR_NS dir, TelescopeMotionCommand command)
 {
     DEBUG(DBG_SCOPE, "SkywatcherAPIMount::MoveNS");
 
-    double speed = (dir == MOTION_NORTH) ? (LOW_SPEED_MARGIN / 2) : -(LOW_SPEED_MARGIN / 2);
-    const char *dirStr = (dir == MOTION_NORTH) ? "North" : "South";
+    double speed = (dir == DIRECTION_NORTH) ? (LOW_SPEED_MARGIN / 2) : -(LOW_SPEED_MARGIN / 2);
+    const char *dirStr = (dir == DIRECTION_NORTH) ? "North" : "South";
 
     switch (command)
     {
@@ -535,12 +537,12 @@ bool SkywatcherAPIMount::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand co
     return true;
 }
 
-bool SkywatcherAPIMount::MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command)
+bool SkywatcherAPIMount::MoveWE(INDI_DIR_WE dir, TelescopeMotionCommand command)
 {
     DEBUG(DBG_SCOPE, "SkywatcherAPIMount::MoveWE");
 
-    double speed = (dir == MOTION_WEST) ? (LOW_SPEED_MARGIN / 2) : -(LOW_SPEED_MARGIN / 2);
-    const char *dirStr = (dir == MOTION_WEST) ? "West" : "East";
+    double speed = (dir == DIRECTION_WEST) ? (LOW_SPEED_MARGIN / 2) : -(LOW_SPEED_MARGIN / 2);
+    const char *dirStr = (dir == DIRECTION_WEST) ? "West" : "East";
 
     switch (command)
     {
@@ -664,7 +666,7 @@ bool SkywatcherAPIMount::ReadScopeStatus()
 
 bool SkywatcherAPIMount::saveConfigItems(FILE *fp)
 {
-    SaveConfigProperties(fp);
+    SaveAlignmentConfigProperties(fp);
 
     return INDI::Telescope::saveConfigItems(fp);
 }
@@ -937,6 +939,7 @@ bool SkywatcherAPIMount::updateProperties()
 
         // Start the timer if we need one
         // SetTimer(POLLMS);
+        return true;
     }
     else
     {
@@ -950,6 +953,7 @@ bool SkywatcherAPIMount::updateProperties()
         deleteProperty(AxisTwoStateV.name);
         deleteProperty(AxisOneEncoderValuesV.name);
         deleteProperty(AxisTwoEncoderValuesV.name);
+        return true;
     }
 }
 
