@@ -87,7 +87,7 @@ void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[],
 }
 void ISSnoopDevice (XMLEle *root)
 {
-    INDI_UNUSED(root);
+   telescope_sim->ISSnoopDevice(root);
 }
 
 
@@ -96,7 +96,6 @@ ScopeSim::ScopeSim()
     //ctor
     currentRA=0;
     currentDEC=90;
-    Parked=false;
 
     forceMeridianFlip = false;
 
@@ -106,7 +105,10 @@ ScopeSim::ScopeSim()
 
     cap.canPark = true;
     cap.canSync = true;
-    cap.canAbort = true;    
+    cap.canAbort = true;
+    cap.hasLocation = true;
+    cap.hasTime = true;
+    cap.nSlewRate=4;
     SetTelescopeCapability(&cap);       
 
     /* initialize random seed: */
@@ -115,7 +117,7 @@ ScopeSim::ScopeSim()
 
 ScopeSim::~ScopeSim()
 {
-    //dtor
+
 }
 
 const char * ScopeSim::getDefaultName()
@@ -134,13 +136,13 @@ bool ScopeSim::initProperties()
     IUFillNumberVector(&EqPENV,EqPEN,2,getDeviceName(),"EQUATORIAL_PE","Periodic Error",MOTION_TAB,IP_RO,60,IPS_IDLE);
 
     /* Enable client to manually add periodic error northward or southward for simulation purposes */
-    IUFillSwitch(&PEErrNSS[MOTION_NORTH], "PE_N", "North", ISS_OFF);
-    IUFillSwitch(&PEErrNSS[MOTION_SOUTH], "PE_S", "South", ISS_OFF);
+    IUFillSwitch(&PEErrNSS[DIRECTION_NORTH], "PE_N", "North", ISS_OFF);
+    IUFillSwitch(&PEErrNSS[DIRECTION_SOUTH], "PE_S", "South", ISS_OFF);
     IUFillSwitchVector(&PEErrNSSP, PEErrNSS, 2, getDeviceName(),"PE_NS", "PE N/S", MOTION_TAB, IP_RW, ISR_ATMOST1, 60, IPS_IDLE);
 
     /* Enable client to manually add periodic error westward or easthward for simulation purposes */
-    IUFillSwitch(&PEErrWES[MOTION_WEST], "PE_W", "West", ISS_OFF);
-    IUFillSwitch(&PEErrWES[MOTION_EAST], "PE_E", "East", ISS_OFF);
+    IUFillSwitch(&PEErrWES[DIRECTION_WEST], "PE_W", "West", ISS_OFF);
+    IUFillSwitch(&PEErrWES[DIRECTION_EAST], "PE_E", "East", ISS_OFF);
     IUFillSwitchVector(&PEErrWESP, PEErrWES, 2, getDeviceName(),"PE_WE", "PE W/E", MOTION_TAB, IP_RW, ISR_ATMOST1, 60, IPS_IDLE);
 
     /* How fast do we guide compared to sidereal rate */
@@ -148,6 +150,12 @@ bool ScopeSim::initProperties()
     IUFillNumber(&GuideRateN[DEC_AXIS], "GUIDE_RATE_NS", "N/S Rate", "%g", 0, 1, 0.1, 0.3);
     IUFillNumberVector(&GuideRateNP, GuideRateN, 2, getDeviceName(), "GUIDE_RATE", "Guiding Rate", MOTION_TAB, IP_RW, 0, IPS_IDLE);
 
+    IUFillSwitch(&SlewRateS[SLEW_GUIDE], "SLEW_GUIDE", "Guide", ISS_OFF);
+    IUFillSwitch(&SlewRateS[SLEW_CENTERING], "SLEW_CENTERING", "Centering", ISS_OFF);
+    IUFillSwitch(&SlewRateS[SLEW_FIND], "SLEW_FIND", "Find", ISS_OFF);
+    IUFillSwitch(&SlewRateS[SLEW_MAX], "SLEW_MAX", "Max", ISS_ON);
+    IUFillSwitchVector(&SlewRateSP, SlewRateS, 4, getDeviceName(), "TELESCOPE_SLEW_RATE", "Slew Rate", MOTION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+
     // Let's simulate it to be an F/7.5 120mm telescope
     ScopeParametersN[0].value = 120;
     ScopeParametersN[1].value = 900;
@@ -156,6 +164,8 @@ bool ScopeSim::initProperties()
 
     TrackState=SCOPE_IDLE;
 
+    SetParkDataType(PARK_RA_DEC);
+
     initGuiderProperties(getDeviceName(), MOTION_TAB);
 
     /* Add debug controls so we may debug driver if necessary */
@@ -181,6 +191,7 @@ void ScopeSim::ISGetProperties (const char *dev)
         defineSwitch(&PEErrWESP);
     }
 
+
     return;
 }
 
@@ -197,6 +208,24 @@ bool ScopeSim::updateProperties()
         defineSwitch(&PEErrNSSP);
         defineSwitch(&PEErrWESP);
 
+        double HA = ln_get_apparent_sidereal_time(ln_get_julian_from_sys());
+        double DEC = 90;
+
+        if (InitPark())
+        {
+            // If loading parking data is successful, we just set the default parking values.
+            SetAxis1ParkDefault(HA);
+            SetAxis2ParkDefault(DEC);
+        }
+        else
+        {
+            // Otherwise, we set all parking data to default in case no parking data is found.
+            SetAxis1Park(HA);
+            SetAxis2Park(DEC);
+            SetAxis1ParkDefault(HA);
+            SetAxis2ParkDefault(DEC);
+        }
+
     }
     else
     {
@@ -217,7 +246,7 @@ bool ScopeSim::Connect()
 
     if(isConnected()) return true;
 
-    rc=Connect(PortT[0].text);
+    rc=Connect(PortT[0].text, atoi(IUFindOnSwitch(&BaudRateSP)->name));
 
     if(rc)
         SetTimer(POLLMS);
@@ -225,8 +254,9 @@ bool ScopeSim::Connect()
     return rc;
 }
 
-bool ScopeSim::Connect(char *port)
+bool ScopeSim::Connect(const char *port, uint16_t baud)
 {
+   DEBUGF(INDI::Logger::DBG_SESSION, "Simulating connecting to port %s with speed %d", port, baud);
    DEBUG(INDI::Logger::DBG_SESSION, "Telescope simulator is online.");
    return true;
 }
@@ -269,32 +299,58 @@ bool ScopeSim::ReadScopeStatus()
     else
         da_dec = FINE_SLEW_RATE *dt;
 
-    switch (MovementNSSP.s)
+    if (MovementNSSP.s == IPS_BUSY || MovementWESP.s == IPS_BUSY)
     {
-       case IPS_BUSY:
-        if (MovementNSS[MOTION_NORTH].s == ISS_ON)
-            currentDEC += da_dec;
-        else if (MovementNSS[MOTION_SOUTH].s == ISS_ON)
-            currentDEC -= da_dec;
+        int rate = IUFindOnSwitchIndex(&SlewRateSP);
+
+        switch (rate)
+        {
+            case SLEW_GUIDE:
+                da_ra  = FINE_SLEW_RATE *dt*0.05;
+                da_dec = FINE_SLEW_RATE *dt*0.05;
+                break;
+
+            case SLEW_CENTERING:
+                da_ra  = FINE_SLEW_RATE *dt*.1;
+                da_dec = FINE_SLEW_RATE *dt*.1;
+                break;
+
+            case SLEW_FIND:
+                da_ra  = SLEW_RATE *dt;
+                da_dec = SLEW_RATE *dt;
+                break;
+
+            default:
+                da_ra  = GOTO_RATE *dt;
+                da_dec = GOTO_RATE *dt;
+                break;
+        }
+
+        switch (MovementNSSP.s)
+        {
+           case IPS_BUSY:
+            if (MovementNSS[DIRECTION_NORTH].s == ISS_ON)
+                currentDEC += da_dec;
+            else if (MovementNSS[DIRECTION_SOUTH].s == ISS_ON)
+                currentDEC -= da_dec;
+
+            break;
+        }
+
+        switch (MovementWESP.s)
+        {
+            case IPS_BUSY:
+
+            if (MovementWES[DIRECTION_WEST].s == ISS_ON)
+                currentRA += da_ra/15.;
+            else if (MovementWES[DIRECTION_EAST].s == ISS_ON)
+                currentRA -= da_ra/15.;
+
+            break;
+        }
 
         NewRaDec(currentRA, currentDEC);
         return true;
-        break;
-    }
-
-    switch (MovementWESP.s)
-    {
-        case IPS_BUSY:
-
-        if (MovementWES[MOTION_WEST].s == ISS_ON)
-            currentRA += da_ra/15.;
-        else if (MovementWES[MOTION_EAST].s == ISS_ON)
-            currentRA -= da_ra/15.;
-
-        NewRaDec(currentRA, currentDEC);
-        return true;
-        break;
-
     }
 
     /* Process per current state. We check the state of EQUATORIAL_EOD_COORDS_REQUEST and act acoordingly */
@@ -373,18 +429,18 @@ bool ScopeSim::ReadScopeStatus()
             }
             else
             {
-                TrackState = SCOPE_PARKED;
-                IUResetSwitch(&ParkSP);
-                ParkSP.s=IPS_OK;
-                IDSetSwitch(&ParkSP,NULL);
-                EqNP.s = IPS_IDLE;
-                DEBUG(INDI::Logger::DBG_SESSION,"Telescope parked successfully.");
+                SetParked(true);
+                EqNP.s = IPS_IDLE;                
             }
         }
 
         break;
 
     case SCOPE_IDLE:
+        currentRA += (SID_RATE*dt)/15.0;
+        currentRA = range24(currentRA);
+        break;
+
     case SCOPE_TRACKING:
         /* tracking */
 
@@ -423,6 +479,12 @@ bool ScopeSim::ReadScopeStatus()
           else              
               guiderNSTarget[ns_guide_dir] = 0;
 
+          if (guiderNSTarget[ns_guide_dir] == 0)
+          {
+              GuideNSNP.s = IPS_IDLE;
+              IDSetNumber(&GuideNSNP, NULL);
+          }
+
           EqPEN[DEC_AXIS].value += dec_guide_dt;
 
           }
@@ -437,6 +499,12 @@ bool ScopeSim::ReadScopeStatus()
           else
                 guiderEWTarget[we_guide_dir] = 0;
 
+          if (guiderEWTarget[we_guide_dir] == 0)
+          {
+              GuideWENP.s = IPS_IDLE;
+              IDSetNumber(&GuideWENP, NULL);
+          }
+
           EqPEN[RA_AXIS].value += ra_guide_dt;
 
           }
@@ -467,11 +535,11 @@ bool ScopeSim::ReadScopeStatus()
         {
             last_dx=dx;
             last_dy=dy;
-            DEBUGF(INDI::Logger::DBG_DEBUG, "dt is %g\n", dt);
-            DEBUGF(INDI::Logger::DBG_DEBUG, "RA Displacement (%c%s) %s -- %s of target RA %s\n", dx >= 0 ? '+' : '-', RA_DISP, RA_PE,  (EqPEN[RA_AXIS].value - targetRA) > 0 ? "East" : "West", RA_TARGET);
-            DEBUGF(INDI::Logger::DBG_DEBUG, "DEC Displacement (%c%s) %s -- %s of target RA %s\n", dy >= 0 ? '+' : '-', DEC_DISP, DEC_PE, (EqPEN[DEC_AXIS].value - targetDEC) > 0 ? "North" : "South", DEC_TARGET);
-            DEBUGF(INDI::Logger::DBG_DEBUG, "RA Guide Correction (%g) %s -- Direction %s\n", ra_guide_dt, RA_GUIDE, ra_guide_dt > 0 ? "East" : "West");
-            DEBUGF(INDI::Logger::DBG_DEBUG, "DEC Guide Correction (%g) %s -- Direction %s\n", dec_guide_dt, DEC_GUIDE, dec_guide_dt > 0 ? "North" : "South");
+            //DEBUGF(INDI::Logger::DBG_DEBUG, "dt is %g\n", dt);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "RA Displacement (%c%s) %s -- %s of target RA %s", dx >= 0 ? '+' : '-', RA_DISP, RA_PE,  (EqPEN[RA_AXIS].value - targetRA) > 0 ? "East" : "West", RA_TARGET);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "DEC Displacement (%c%s) %s -- %s of target RA %s", dy >= 0 ? '+' : '-', DEC_DISP, DEC_PE, (EqPEN[DEC_AXIS].value - targetDEC) > 0 ? "North" : "South", DEC_TARGET);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "RA Guide Correction (%g) %s -- Direction %s", ra_guide_dt, RA_GUIDE, ra_guide_dt > 0 ? "East" : "West");
+            DEBUGF(INDI::Logger::DBG_DEBUG, "DEC Guide Correction (%g) %s -- Direction %s", dec_guide_dt, DEC_GUIDE, dec_guide_dt > 0 ? "North" : "South");
         }
 
         if (ns_guide_dir != -1 || we_guide_dir != -1)
@@ -496,7 +564,6 @@ bool ScopeSim::ReadScopeStatus()
 
 bool ScopeSim::Goto(double r,double d)
 {
-    //IDLog("ScopeSim Goto\n");
     targetRA=r;
     targetDEC=d;
     char RAStr[64], DecStr[64];
@@ -529,7 +596,6 @@ bool ScopeSim::Goto(double r,double d)
        }
    }
 
-   Parked=false;
    TrackState = SCOPE_SLEWING;
 
    EqNP.s    = IPS_BUSY;
@@ -540,6 +606,7 @@ bool ScopeSim::Goto(double r,double d)
 
 bool ScopeSim::Sync(double ra, double dec)
 {
+
     currentRA  = ra;
     currentDEC = dec;
 
@@ -560,14 +627,19 @@ bool ScopeSim::Sync(double ra, double dec)
 
 bool ScopeSim::Park()
 {
-    targetRA=0;
-    targetDEC=90;
-    Parked=true;
+    targetRA= GetAxis1Park();
+    targetDEC= GetAxis2Park();
     TrackState = SCOPE_PARKING;
     DEBUG(INDI::Logger::DBG_SESSION,"Parking telescope in progress...");
     return true;
 }
 
+bool ScopeSim::UnPark()
+{
+    SetParked(false);
+    return true;
+}
+
 bool ScopeSim::ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n)
 {
     //  first check if it's for our device
@@ -599,13 +671,25 @@ bool ScopeSim::ISNewSwitch (const char *dev, const char *name, ISState *states,
 {
     if(strcmp(dev,getDeviceName())==0)
     {
+        // Slew mode
+        if (!strcmp (name, SlewRateSP.name))
+        {
+
+          if (IUUpdateSwitch(&SlewRateSP, states, names, n) < 0)
+              return false;
+
+          SlewRateSP.s = IPS_OK;
+          IDSetSwitch(&SlewRateSP, NULL);
+          return true;
+        }
+
         if(strcmp(name,"PE_NS")==0)
         {
             IUUpdateSwitch(&PEErrNSSP,states,names,n);
 
             PEErrNSSP.s = IPS_OK;
 
-            if (PEErrNSS[MOTION_NORTH].s == ISS_ON)
+            if (PEErrNSS[DIRECTION_NORTH].s == ISS_ON)
             {
                 EqPEN[DEC_AXIS].value += SID_RATE * GuideRateN[DEC_AXIS].value;
                 DEBUGF(INDI::Logger::DBG_DEBUG, "Simulating PE in NORTH direction for value of %g", SID_RATE);
@@ -629,7 +713,7 @@ bool ScopeSim::ISNewSwitch (const char *dev, const char *name, ISState *states,
 
             PEErrWESP.s = IPS_OK;
 
-            if (PEErrWES[MOTION_WEST].s == ISS_ON)
+            if (PEErrWES[DIRECTION_WEST].s == ISS_ON)
             {
                 EqPEN[RA_AXIS].value -= SID_RATE/15. * GuideRateN[RA_AXIS].value;
                 DEBUGF(INDI::Logger::DBG_DEBUG, "Simulator PE in WEST direction for value of %g", SID_RATE);
@@ -695,64 +779,60 @@ bool ScopeSim::Abort()
 }
 
 
-bool ScopeSim::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command)
+bool ScopeSim::MoveNS(INDI_DIR_NS dir, TelescopeMotionCommand command)
 {
+    if (TrackState == SCOPE_PARKED)
+    {
+        DEBUG(INDI::Logger::DBG_ERROR, "Please unpark the mount before issuing any motion commands.");
+        return false;
+    }
+
     return true;
 }
 
-bool ScopeSim::MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command)
+bool ScopeSim::MoveWE(INDI_DIR_WE dir, TelescopeMotionCommand command)
 {
+    if (TrackState == SCOPE_PARKED)
+    {
+        DEBUG(INDI::Logger::DBG_ERROR, "Please unpark the mount before issuing any motion commands.");
+        return false;
+    }
+
     return true;
 }
 
-bool ScopeSim::GuideNorth(float ms)
+IPState ScopeSim::GuideNorth(float ms)
 {
     guiderNSTarget[GUIDE_NORTH] = ms;
     guiderNSTarget[GUIDE_SOUTH] = 0;
-    return true;
+    return IPS_BUSY;
 }
 
-bool ScopeSim::GuideSouth(float ms)
+IPState ScopeSim::GuideSouth(float ms)
 {
     guiderNSTarget[GUIDE_SOUTH] = ms;
     guiderNSTarget[GUIDE_NORTH] = 0;
-    return true;
+    return IPS_BUSY;
 
 }
 
-bool ScopeSim::GuideEast(float ms)
+IPState ScopeSim::GuideEast(float ms)
 {
 
     guiderEWTarget[GUIDE_EAST] = ms;
     guiderEWTarget[GUIDE_WEST] = 0;
-    return true;
+    return IPS_BUSY;
 
 }
 
-bool ScopeSim::GuideWest(float ms)
+IPState ScopeSim::GuideWest(float ms)
 {
     guiderEWTarget[GUIDE_WEST] = ms;
     guiderEWTarget[GUIDE_EAST] = 0;
-    return true;
+    return IPS_BUSY;
 
 }
 
-double ScopeSim::range24(double r)
-{
-  double res = r;
-  while (res<0.0) res+=24.0;
-  while (res>24.0) res-=24.0;
-  return res;
-}
-
-double ScopeSim::range360(double r)
-{
-  double res = r;
-  while (res<0.0) res+=360.0;
-  while (res>360.0) res-=360.0;
-  return res;
-}
-
 bool ScopeSim::updateLocation(double latitude, double longitude, double elevation)
 {
   INDI_UNUSED(elevation);
@@ -763,6 +843,24 @@ bool ScopeSim::updateLocation(double latitude, double longitude, double elevatio
       lnobserver.lng -= 360;
   lnobserver.lat =  latitude;
 
-  DEBUGF(INDI::Logger::DBG_SESSION,"Located updated: long = %g lat = %g", lnobserver.lng, lnobserver.lat);
+  DEBUGF(INDI::Logger::DBG_SESSION,"Location updated: Longitude (%g) Latitude (%g)", lnobserver.lng, lnobserver.lat);
   return true;
 }
+
+void ScopeSim::SetCurrentPark()
+{
+    SetAxis1Park(currentRA);
+    SetAxis2Park(currentDEC);
+}
+
+void ScopeSim::SetDefaultPark()
+{
+    // By default set RA to HA
+    SetAxis1Park(ln_get_apparent_sidereal_time(ln_get_julian_from_sys()));
+
+    // Set DEC to 90 or -90 depending on the hemisphere
+    SetAxis2Park( (LocationN[LOCATION_LATITUDE].value > 0) ? 90 : -90);
+
+}
+
+
