@@ -3,8 +3,7 @@
 
 #include "indibase/indiguiderinterface.h"
 #include "indibase/inditelescope.h"
-
-
+#include "indicontroller.h"
 
 class ScopeSim : public INDI::Telescope, public INDI::GuiderInterface
 {
@@ -14,35 +13,38 @@ public:
 
     virtual const char *getDefaultName();
     virtual bool Connect();
-    virtual bool Connect(char *);
+    virtual bool Connect(const char *port, uint16_t baud);
     virtual bool Disconnect();
     virtual bool ReadScopeStatus();
     virtual bool initProperties();
     virtual void ISGetProperties (const char *dev);
     virtual bool updateProperties();
+
     virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
     virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
 
     protected:
 
-    virtual bool MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command);
-    virtual bool MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command);
+    virtual bool MoveNS(INDI_DIR_NS dir, TelescopeMotionCommand command);
+    virtual bool MoveWE(INDI_DIR_WE dir, TelescopeMotionCommand command);
     virtual bool Abort();
 
-    virtual bool GuideNorth(float ms);
-    virtual bool GuideSouth(float ms);
-    virtual bool GuideEast(float ms);
-    virtual bool GuideWest(float ms);
+    virtual IPState GuideNorth(float ms);
+    virtual IPState GuideSouth(float ms);
+    virtual IPState GuideEast(float ms);
+    virtual IPState GuideWest(float ms);
     virtual bool updateLocation(double latitude, double longitude, double elevation);
 
     bool Goto(double,double);
     bool Park();
+    bool UnPark();
     bool Sync(double ra, double dec);
 
-    private:
+    // Parking
+    virtual void SetCurrentPark();
+    virtual void SetDefaultPark();
 
-    double range24(double r);
-    double range360(double r);
+    private:
 
     double currentRA;
     double currentDEC;
@@ -53,7 +55,6 @@ public:
     ln_hrz_posn lnaltaz;
     bool forceMeridianFlip;
     unsigned int DBG_SCOPE;
-    bool Parked;
 
     double guiderEWTarget[2];
     double guiderNSTarget[2];
