@@ -31,8 +31,6 @@ class SimpleCCD : public INDI::CCD
 public:
     SimpleCCD();
 
-    void ISGetProperties(const char *dev);
-
 protected:
     // General device functions
     bool Connect();
@@ -62,10 +60,6 @@ private:
     float TemperatureRequest;
     int   timerID;
 
-    // We declare the CCD temperature property
-    INumber TemperatureN[1];
-    INumberVectorProperty TemperatureNP;
-
 };
 
 #endif // SIMPLECCD_H
