@@ -17,6 +17,9 @@
 /** \file simplescope.h
     \brief Construct a basic INDI telescope device that simulates GOTO commands.
     \author Jasem Mutlaq
+
+    \example simplescope.h
+    A simple GOTO telescope that simulator slewing operation.
 */
 
 #include "indibase/inditelescope.h"
@@ -31,6 +34,7 @@ protected:
     bool Connect();
     bool Disconnect();
     const char *getDefaultName();
+    bool initProperties();
 
     // Telescoe specific functions
     bool ReadScopeStatus();
@@ -43,6 +47,8 @@ private:
     double targetRA;
     double targetDEC;
 
+    unsigned int DBG_SCOPE;
+
 };
 
 #endif // SIMPLESCOPE_H
