@@ -31,6 +31,7 @@
 #include <errno.h>
 #include <dirent.h>
 
+#include <libnova.h>
 #include <fitsio.h>
 
 const char *IMAGE_SETTINGS_TAB  = "Image Settings";
@@ -38,6 +39,7 @@ const char *IMAGE_INFO_TAB      = "Image Info";
 const char *GUIDE_HEAD_TAB      = "Guider Head";
 const char *GUIDE_CONTROL_TAB   = "Guider Control";
 const char *RAPIDGUIDE_TAB      = "Rapid Guide";
+const char *WCS_TAB             = "WCS";
 
 CCDChip::CCDChip()
 {
@@ -235,7 +237,7 @@ void CCDChip::setNAxis(int value)
 
 void CCDChip::setImageExtension(const char *ext)
 {
-    strncpy(imageExtention, ext, MAXINDINAME);
+    strncpy(imageExtention, ext, MAXINDIBLOBFMT);
 }
 
 INDI::CCD::CCD()
@@ -254,6 +256,7 @@ INDI::CCD::CCD()
     InGuideExposure=false;
     RapidGuideEnabled=false;
     GuiderRapidGuideEnabled=false;
+    ValidCCDRotation=false;
 
     AutoLoop=false;
     SendImage=false;
@@ -268,6 +271,7 @@ INDI::CCD::CCD()
 
     RA=-1000;
     Dec=-1000;
+    Aperture=FocalLength=-1;
 }
 
 INDI::CCD::~CCD()
@@ -407,7 +411,7 @@ bool INDI::CCD::initProperties()
     IUFillNumber(&GuideCCD.RapidGuideDataN[2],"GUIDESTAR_FIT","Guide star fit","%5.2f",0,1024,0,0);
     IUFillNumberVector(&GuideCCD.RapidGuideDataNP,GuideCCD.RapidGuideDataN,3,getDeviceName(),"GUIDER_RAPID_GUIDE_DATA","Rapid Guide Data",RAPIDGUIDE_TAB,IP_RO,60,IPS_IDLE);
 
-    // CCD Class Init
+    // CCD Class Init    
 
     IUFillText(&BayerT[0],"CFA_OFFSET_X","X Offset","0");
     IUFillText(&BayerT[1],"CFA_OFFSET_Y","Y Offset","0");
@@ -420,7 +424,7 @@ bool INDI::CCD::initProperties()
     IUFillSwitchVector(&UploadSP, UploadS, 3, getDeviceName(), "UPLOAD_MODE", "Upload", OPTIONS_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
 
     IUFillText(&UploadSettingsT[0],"UPLOAD_DIR","Dir","");
-    IUFillText(&UploadSettingsT[1],"UPLOAD_PREFIX","Prefix","IMAGE_XX");
+    IUFillText(&UploadSettingsT[1],"UPLOAD_PREFIX","Prefix","IMAGE_XXX");
     IUFillTextVector(&UploadSettingsTP,UploadSettingsT,2,getDeviceName(),"UPLOAD_SETTINGS","Upload Settings",OPTIONS_TAB,IP_RW,60,IPS_IDLE);
 
     IUFillText(&ActiveDeviceT[0],"ACTIVE_TELESCOPE","Telescope","Telescope Simulator");
@@ -428,11 +432,23 @@ bool INDI::CCD::initProperties()
     IUFillText(&ActiveDeviceT[2],"ACTIVE_FILTER","Filter","CCD Simulator");
     IUFillTextVector(&ActiveDeviceTP,ActiveDeviceT,3,getDeviceName(),"ACTIVE_DEVICES","Snoop devices",OPTIONS_TAB,IP_RW,60,IPS_IDLE);
 
+    IUFillSwitch(&WorldCoordS[0], "WCS_ENABLE", "Enable", ISS_OFF);
+    IUFillSwitch(&WorldCoordS[1], "WCS_DISABLE", "Disable", ISS_ON);
+    IUFillSwitchVector(&WorldCoordSP, WorldCoordS, 2, getDeviceName(), "WCS_CONTROL", "WCS", WCS_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+
+    IUFillSwitch(&TelescopeTypeS[0], "TELESCOPE_PRIMARY", "Primary", ISS_ON);
+    IUFillSwitch(&TelescopeTypeS[1], "TELESCOPE_GUIDE", "Guide", ISS_OFF);
+    IUFillSwitchVector(&TelescopeTypeSP, TelescopeTypeS, 2, getDeviceName(), "TELESCOPE_TYPE", "Telescope", WCS_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+
+    IUFillNumber(&CCDRotationN[0],"CCD_ROTATION_VALUE","Rotation","%g",-360,360,1,0);
+    IUFillNumberVector(&CCDRotationNP,CCDRotationN,1,getDeviceName(),"CCD_ROTATION","CCD FOV", WCS_TAB,IP_RW,60,IPS_IDLE);
+
     IUFillNumber(&EqN[0],"RA","Ra (hh:mm:ss)","%010.6m",0,24,0,0);
     IUFillNumber(&EqN[1],"DEC","Dec (dd:mm:ss)","%010.6m",-90,90,0,0);
     IUFillNumberVector(&EqNP,EqN,2,ActiveDeviceT[0].text,"EQUATORIAL_EOD_COORD","EQ Coord","Main Control",IP_RW,60,IPS_IDLE);
 
     IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_EOD_COORD");
+    IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
     IDSnoopDevice(ActiveDeviceT[2].text,"FILTER_SLOT");
     IDSnoopDevice(ActiveDeviceT[2].text,"FILTER_NAME");
 
@@ -530,6 +546,7 @@ bool INDI::CCD::updateProperties()
           defineNumber(&GuideCCD.RapidGuideDataNP);
         }
         defineText(&ActiveDeviceTP);
+        defineSwitch(&WorldCoordSP);
         defineSwitch(&UploadSP);
 
         if (UploadSettingsT[0].text == NULL)
@@ -588,6 +605,12 @@ bool INDI::CCD::updateProperties()
         if (capability.hasBayer)
             deleteProperty(BayerTP.name);
         deleteProperty(ActiveDeviceTP.name);
+        if (WorldCoordS[0].s == ISS_ON)
+        {
+            deleteProperty(TelescopeTypeSP.name);
+            deleteProperty(CCDRotationNP.name);
+        }
+        deleteProperty(WorldCoordSP.name);
         deleteProperty(UploadSP.name);
         deleteProperty(UploadSettingsTP.name);
     }
@@ -611,6 +634,34 @@ bool INDI::CCD::ISSnoopDevice (XMLEle *root)
             Dec=newdec;
         }
      }
+     else if (!strcmp(propName, "TELESCOPE_INFO"))
+     {
+          for (ep = nextXMLEle(root, 1) ; ep != NULL ; ep = nextXMLEle(root, 0))
+          {
+              const char *name = findXMLAttValu(ep, "name");
+
+              if (!strcmp(name, "TELESCOPE_APERTURE"))
+              {
+                  if (TelescopeTypeS[0].s == ISS_ON)
+                      Aperture = atof(pcdataXMLEle(ep));
+              }
+              else if (!strcmp(name, "TELESCOPE_FOCAL_LENGTH"))
+              {
+                  if (TelescopeTypeS[0].s == ISS_ON)
+                      FocalLength = atof(pcdataXMLEle(ep));
+              }
+              else if (!strcmp(name, "GUIDER_APERTURE"))
+              {
+                  if (TelescopeTypeS[1].s == ISS_ON)
+                      Aperture = atof(pcdataXMLEle(ep));
+              }
+              else if (!strcmp(name, "GUIDER_FOCAL_LENGTH"))
+              {
+                  if (TelescopeTypeS[1].s == ISS_ON)
+                      FocalLength = atof(pcdataXMLEle(ep));
+              }
+          }
+     }
      else if (!strcmp(propName, "FILTER_NAME"))
      {
          FilterNames.clear();
@@ -647,6 +698,7 @@ bool INDI::CCD::ISNewText (const char *dev, const char *name, char *texts[], cha
             // Update the property name!
             strncpy(EqNP.device, ActiveDeviceT[0].text, MAXINDIDEVICE);
             IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_EOD_COORD");
+            IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
             IDSnoopDevice(ActiveDeviceT[2].text,"FILTER_SLOT");
             IDSnoopDevice(ActiveDeviceT[2].text,"FILTER_NAME");
 
@@ -687,6 +739,14 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
         //  Now lets see if it's something we process here
         if(strcmp(name,"CCD_EXPOSURE")==0)
         {
+            if (values[0] <  PrimaryCCD.ImageExposureN[0].min || values[0] > PrimaryCCD.ImageExposureN[0].max)
+            {
+                DEBUGF(INDI::Logger::DBG_ERROR, "Requested exposure value (%g) seconds out of bounds [%g,%g].", values[0], PrimaryCCD.ImageExposureN[0].min, PrimaryCCD.ImageExposureN[0].max);
+                PrimaryCCD.ImageExposureNP.s=IPS_ALERT;
+                IDSetNumber(&PrimaryCCD.ImageExposureNP,NULL);
+                return false;
+            }
+
             PrimaryCCD.ImageExposureN[0].value = ExposureTime = values[0];
 
             if (PrimaryCCD.ImageExposureNP.s==IPS_BUSY)
@@ -702,6 +762,14 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
 
         if(strcmp(name,"GUIDER_EXPOSURE")==0)
         {
+            if (values[0] <  GuideCCD.ImageExposureN[0].min || values[0] > GuideCCD.ImageExposureN[0].max)
+            {
+                DEBUGF(INDI::Logger::DBG_ERROR, "Requested guide exposure value (%g) seconds out of bounds [%g,%g].", values[0], GuideCCD.ImageExposureN[0].min, GuideCCD.ImageExposureN[0].max);
+                GuideCCD.ImageExposureNP.s=IPS_ALERT;
+                IDSetNumber(&GuideCCD.ImageExposureNP,NULL);
+                return false;
+            }
+
             GuideCCD.ImageExposureN[0].value = GuiderExposureTime = values[0];
             GuideCCD.ImageExposureNP.s=IPS_BUSY;
             if (StartGuideExposure(GuiderExposureTime))
@@ -896,7 +964,18 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
             return true;
         }
 
+        // CCD Rotation
+        if (!strcmp(name, CCDRotationNP.name))
+        {
+            IUUpdateNumber(&CCDRotationNP, values, names, n);
+            CCDRotationNP.s = IPS_OK;
+            IDSetNumber(&CCDRotationNP, NULL);
+            ValidCCDRotation=true;
 
+            DEBUGF(INDI::Logger::DBG_SESSION, "CCD FOV rotation updated to %g degrees.", CCDRotationN[0].value);
+
+            return true;
+        }
     }
     //  if we didn't process it, continue up the chain, let somebody else
     //  give it a shot
@@ -923,6 +1002,35 @@ bool INDI::CCD::ISNewSwitch (const char *dev, const char *name, ISState *states,
             return true;
         }
 
+        if (!strcmp(name, TelescopeTypeSP.name))
+        {
+            IUUpdateSwitch(&TelescopeTypeSP, states, names, n);
+            TelescopeTypeSP.s = IPS_OK;
+            IDSetSwitch(&TelescopeTypeSP, NULL);
+            return true;
+        }
+
+        if (!strcmp(name, WorldCoordSP.name))
+        {
+            IUUpdateSwitch(&WorldCoordSP, states, names, n);
+            WorldCoordSP.s = IPS_OK;
+
+            if (WorldCoordS[0].s == ISS_ON)
+            {
+                DEBUG(INDI::Logger::DBG_WARNING, "World Coordinate System is enabled. CCD rotation must be set either manually or by solving the image before proceeding to capture any frames, otherwise the WCS information may be invalid.");
+                defineSwitch(&TelescopeTypeSP);
+                defineNumber(&CCDRotationNP);
+            }
+            else
+            {
+                deleteProperty(TelescopeTypeSP.name);
+                deleteProperty(CCDRotationNP.name);
+            }
+
+            ValidCCDRotation=false;
+            IDSetSwitch(&WorldCoordSP, NULL);
+        }
+
         // Reset
         if(strcmp(name,PrimaryCCD.ResetSP.name)==0)
         {
@@ -1227,6 +1335,8 @@ void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
     double pixSize1,pixSize2;
     unsigned int xbin, ybin;
 
+    setlocale(LC_NUMERIC,"C");
+
     if (targetChip->getNAxis() == 2)
         getMinMax(&min_val, &max_val, targetChip);
 
@@ -1297,14 +1407,91 @@ void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
         fits_update_key_s(fptr, TSTRING, "BAYERPAT", BayerT[2].text, "Bayer color pattern", &status);
     }
 
-    if (RA != -1000 && Dec != -1000)
+    if (targetChip->getFrameType() == CCDChip::LIGHT_FRAME && RA != -1000 && Dec != -1000)
     {
-        fits_update_key_s(fptr, TDOUBLE, "OBJCTRA", &RA, "Object RA", &status);
-        fits_update_key_s(fptr, TDOUBLE, "OBJCTDEC", &Dec, "Object DEC", &status);
+        ln_equ_posn epochPos, J2000Pos;
+        epochPos.ra   = RA*15.0;
+        epochPos.dec  = Dec;
+
+        // Convert from JNow to J2000
+        //TODO use exp_start instead of julian from system
+        ln_get_equ_prec2(&epochPos, ln_get_julian_from_sys(), JD2000, &J2000Pos);
+
+        double raJ2000  = J2000Pos.ra/15.0;
+        double decJ2000 = J2000Pos.dec;
+
+        fits_update_key_s(fptr, TDOUBLE, "OBJCTRA", &raJ2000, "Object RA", &status);
+        fits_update_key_s(fptr, TDOUBLE, "OBJCTDEC", &decJ2000, "Object DEC", &status);       
+
+        int epoch = 2000;
+
+        fits_update_key_s(fptr, TINT, "EPOCH", &epoch, "Epoch", &status);
+        fits_update_key_s(fptr, TINT, "EQUINOX", &epoch, "Equinox", &status);
+
+
+        // Add WCS Info
+        if (WorldCoordS[0].s == ISS_ON && ValidCCDRotation && FocalLength != -1)
+        {
+            raJ2000 *= 15;
+            fits_update_key_s(fptr, TDOUBLE, "CRVAL1", &raJ2000, "CRVAL1", &status);
+            fits_update_key_s(fptr, TDOUBLE, "CRVAL2", &decJ2000, "CRVAL1", &status);
+
+            char radecsys[8] = "FK5";
+            char ctype1[16]  = "RA---TAN";
+            char ctype2[16]  = "DEC--TAN";
+
+            fits_update_key_s(fptr, TSTRING, "RADECSYS", radecsys, "RADECSYS", &status);
+            fits_update_key_s(fptr, TSTRING, "CTYPE1", ctype1, "CTYPE1", &status);
+            fits_update_key_s(fptr, TSTRING, "CTYPE2", ctype2, "CTYPE2", &status);
+
+            double crpix1 = targetChip->getSubW()/targetChip->getBinX()/2.0;
+            double crpix2 = targetChip->getSubH()/targetChip->getBinY()/2.0;
+
+            fits_update_key_s(fptr, TDOUBLE, "CRPIX1", &crpix1, "CRPIX1", &status);
+            fits_update_key_s(fptr, TDOUBLE, "CRPIX2", &crpix2, "CRPIX2", &status);
+
+            double secpix1 = pixSize1 / FocalLength * 206.3 * targetChip->getBinX();
+            double secpix2 = pixSize2 / FocalLength * 206.3 * targetChip->getBinY();
+
+            //double secpix1 = pixSize1 / FocalLength * 206.3;
+            //double secpix2 = pixSize2 / FocalLength * 206.3;
+
+            fits_update_key_s(fptr, TDOUBLE, "SECPIX1", &secpix1, "SECPIX1", &status);
+            fits_update_key_s(fptr, TDOUBLE, "SECPIX2", &secpix2, "SECPIX2", &status);
+
+            double degpix1 =  secpix1 / 3600.0;
+            double degpix2 =  secpix2 / 3600.0;
+
+            fits_update_key_s(fptr, TDOUBLE, "CDELT1", &degpix1, "CDELT1", &status);
+            fits_update_key_s(fptr, TDOUBLE, "CDELT2", &degpix2, "CDELT2", &status);
+
+            // Rotation is CW, we need to convert it to CCW per CROTA1 definition
+            double rotation = 360 - CCDRotationN[0].value;
+            if (rotation > 360)
+              rotation -= 360;
+
+            fits_update_key_s(fptr, TDOUBLE, "CROTA1", &rotation, "CROTA1", &status);
+            fits_update_key_s(fptr, TDOUBLE, "CROTA2", &rotation, "CROTA2", &status);
+
+            /*double cd[4];
+            cd[0] = degpix1;
+            cd[1] = 0;
+            cd[2] = 0;
+            cd[3] = degpix2;
+
+            fits_update_key_s(fptr, TDOUBLE, "CD1_1", &cd[0], "CD1_1", &status);
+            fits_update_key_s(fptr, TDOUBLE, "CD1_2", &cd[1], "CD1_2", &status);
+            fits_update_key_s(fptr, TDOUBLE, "CD2_1", &cd[2], "CD2_1", &status);
+            fits_update_key_s(fptr, TDOUBLE, "CD2_2", &cd[3], "CD2_2", &status);*/
+
+        }
+
     }
 
-    fits_update_key_s(fptr, TSTRING, "INSTRUME", dev_name, "CCD Name", &status);
     fits_update_key_s(fptr, TSTRING, "DATE-OBS", exp_start, "UTC start date of observation", &status);
+    fits_write_comment(fptr, "Generated by INDI", &status);
+
+    setlocale(LC_NUMERIC,"");
 
 }
 
@@ -1650,10 +1837,10 @@ bool INDI::CCD::uploadFile(CCDChip * targetChip, const void *fitsData, size_t to
 
         if (maxIndex > 0)
         {
-            char indexString[3];
-            snprintf(indexString, 3, "%02d", maxIndex);
+            char indexString[4];
+            snprintf(indexString, 4, "%03d", maxIndex);
             std::string prefixIndex = indexString;
-            prefix.replace(prefix.find("XX"), 2, prefixIndex);
+            prefix.replace(prefix.find("XXX"), 3, prefixIndex);
         }
 
         snprintf(imageFileName, MAXRBUF, "%s/%s%s", UploadSettingsT[0].text, prefix.c_str(), targetChip->FitsB.format);
@@ -1742,6 +1929,11 @@ bool INDI::CCD::saveConfigItems(FILE *fp)
     IUSaveConfigText(fp, &ActiveDeviceTP);
     IUSaveConfigSwitch(fp, &UploadSP);
     IUSaveConfigText(fp, &UploadSettingsTP);
+    //IUSaveConfigSwitch(fp, &WorldCoordSP);
+    IUSaveConfigSwitch(fp, &TelescopeTypeSP);
+
+    //if (ValidCCDRotation)
+    //    IUSaveConfigNumber(fp, &CCDRotationNP);
 
     IUSaveConfigSwitch(fp, &PrimaryCCD.CompressSP);
 
@@ -1760,24 +1952,32 @@ bool INDI::CCD::saveConfigItems(FILE *fp)
     return true;
 }
 
-bool INDI::CCD::GuideNorth(float ms)
+IPState INDI::CCD::GuideNorth(float ms)
 {
-    return false;
+    INDI_UNUSED(ms);
+    DEBUG(INDI::Logger::DBG_ERROR, "The CCD does not support guiding.");
+    return IPS_ALERT;
 }
 
-bool INDI::CCD::GuideSouth(float ms)
+IPState INDI::CCD::GuideSouth(float ms)
 {
-    return false;
+    INDI_UNUSED(ms);
+    DEBUG(INDI::Logger::DBG_ERROR, "The CCD does not support guiding.");
+    return IPS_ALERT;
 }
 
-bool INDI::CCD::GuideEast(float ms)
+IPState INDI::CCD::GuideEast(float ms)
 {
-    return false;
+    INDI_UNUSED(ms);
+    DEBUG(INDI::Logger::DBG_ERROR, "The CCD does not support guiding.");
+    return IPS_ALERT;
 }
 
-bool INDI::CCD::GuideWest(float ms)
+IPState INDI::CCD::GuideWest(float ms)
 {
-    return false;
+    INDI_UNUSED(ms);
+    DEBUG(INDI::Logger::DBG_ERROR, "The CCD does not support guiding.");
+    return IPS_ALERT;
 }
 
 void INDI::CCD::getMinMax(double *min, double *max, CCDChip *targetChip)
@@ -1851,11 +2051,11 @@ int INDI::CCD::getFileIndex(const char *dir, const char *prefix, const char *ext
     std::vector<std::string> files = std::vector<std::string>();
 
     std::string prefixIndex = prefix;
-    if (prefixIndex.find("XX") == std::string::npos)
+    if (prefixIndex.find("XXX") == std::string::npos)
         return 0;
 
     std::string prefixSearch = prefix;
-    prefixSearch.replace(prefixSearch.find("XX"), 2, "");
+    prefixSearch.replace(prefixSearch.find("XXX"), 3, "");
 
     dpdf = opendir(dir);
     if (dpdf != NULL)
@@ -1872,7 +2072,7 @@ int INDI::CCD::getFileIndex(const char *dir, const char *prefix, const char *ext
     int maxIndex=0;
 
     std::string filterIndex = "%d";
-    prefixIndex.replace(prefixIndex.find("XX"), 2, filterIndex);
+    prefixIndex.replace(prefixIndex.find("XXX"), 3, filterIndex);
     char filter[MAXRBUF];
     snprintf(filter, MAXRBUF, "%s%s", prefixIndex.c_str(), ext);
     for (int i=0; i < files.size(); i++)
@@ -1887,4 +2087,7 @@ int INDI::CCD::getFileIndex(const char *dir, const char *prefix, const char *ext
 
 }
 
-
+void INDI::CCD::GuideComplete(INDI_EQ_AXIS axis)
+{
+    INDI::GuiderInterface::GuideComplete(axis);
+}
