@@ -359,7 +359,7 @@ private:
     ISwitchVectorProperty RapidGuideSP;
 
     ISwitch RapidGuideSetupS[3];
-    ISwitchVectorProperty RapidGuideSetupSP;
+    ISwitchVectorProperty RapidGuideSetupSP;    
 
     INumber RapidGuideDataN[3];
     INumberVectorProperty RapidGuideDataNP;
@@ -593,28 +593,28 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
             \note This function is not implemented in INDI::CCD, it must be implemented in the child class
             \return True if successful, false otherwise.
         */
-        virtual bool GuideNorth(float ms);
+        virtual IPState GuideNorth(float ms);
 
         /** \brief Guide southward for ms milliseconds
             \param ms Duration in milliseconds.
             \note This function is not implemented in INDI::CCD, it must be implemented in the child class
             \return 0 if successful, -1 otherwise.
         */
-        virtual bool GuideSouth(float ms);
+        virtual IPState GuideSouth(float ms);
 
         /** \brief Guide easward for ms milliseconds
             \param ms Duration in milliseconds.
             \note This function is not implemented in INDI::CCD, it must be implemented in the child class
             \return 0 if successful, -1 otherwise.
         */
-        virtual bool GuideEast(float ms);
+        virtual IPState GuideEast(float ms);
 
         /** \brief Guide westward for ms milliseconds
             \param ms Duration in milliseconds.
             \note This function is not implemented in INDI::CCD, it must be implemented in the child class
             \return 0 if successful, -1 otherwise.
         */
-        virtual bool GuideWest(float ms);
+        virtual IPState GuideWest(float ms);
 
         /** \brief Add FITS keywords to a fits file
             \param fptr pointer to a valid FITS file.
@@ -637,18 +637,20 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
         */
         virtual void addFITSKeywords(fitsfile *fptr, CCDChip *targetChip);
 
-        /* A function to just remove GCC warnings about deprecated conversion */
+        /** A function to just remove GCC warnings about deprecated conversion */
         void fits_update_key_s(fitsfile* fptr, int type, std::string name, void* p, std::string explanation, int* status);
 
         /**
          * @brief activeDevicesUpdated Inform children that ActiveDevices property was updated so they can snoop on the updated devices if desired.
          */
-        virtual void activeDevicesUpdated() {}
+        virtual void activeDevicesUpdated() {}        
 
         virtual bool saveConfigItems(FILE *fp);
 
+        void GuideComplete(INDI_EQ_AXIS axis);
 
         double RA, Dec;
+        double FocalLength, Aperture;
         bool InExposure;
         bool InGuideExposure;
         bool RapidGuideEnabled;
@@ -677,6 +679,15 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
         ITextVectorProperty ActiveDeviceTP;
         IText ActiveDeviceT[3];
 
+        ISwitch WorldCoordS[2];
+        ISwitchVectorProperty WorldCoordSP;
+
+        INumber CCDRotationN[1];
+        INumberVectorProperty CCDRotationNP;
+
+        ISwitch TelescopeTypeS[2];
+        ISwitchVectorProperty TelescopeTypeSP;
+
         INumber                 TemperatureN[1];
         INumberVectorProperty   TemperatureNP;
 
@@ -692,6 +703,8 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
      private:
         CCDCapability capability;
 
+        bool ValidCCDRotation;
+
         bool uploadFile(CCDChip * targetChip, const void *fitsData, size_t totalBytes, bool sendImage, bool saveImage);
         void getMinMax(double *min, double *max, CCDChip *targetChip);
         int getFileIndex(const char *dir, const char *prefix, const char *ext);
