@@ -51,7 +51,7 @@ bool INDI::Dome::initProperties()
 
     /* Port */
     IUFillText(&PortT[0], "PORT", "Port", "/dev/ttyUSB0");
-    IUFillTextVector(&PortTP, PortT, 1, getDeviceName(), "DEVICE_PORT", "Ports", MAIN_CONTROL_TAB, IP_RW, 0, IPS_IDLE);
+    IUFillTextVector(&PortTP, PortT, 1, getDeviceName(), "DEVICE_PORT", "Ports", OPTIONS_TAB, IP_RW, 0, IPS_IDLE);
 
     // Presets
     IUFillNumber(&PresetN[0], "Preset 1", "", "%6.2f", 0, 360.0, 1.0, 0);
@@ -112,6 +112,8 @@ bool INDI::Dome::updateProperties()
 {
     if(isConnected())
     {
+        last_dome_motion = -1;
+
         defineText(&ActiveDeviceTP);
 
         if (capability.hasShutter)
@@ -120,10 +122,10 @@ bool INDI::Dome::updateProperties()
         //  Now we add our Dome specific stuff
         defineSwitch(&DomeMotionSP);
 
-        if (capability.variableSpeed)
+        if (capability.hasVariableSpeed)
         {
             defineNumber(&DomeSpeedNP);
-            defineNumber(&DomeTimerNP);
+            //defineNumber(&DomeTimerNP);
         }
         if (capability.canRelMove)
             defineNumber(&DomeRelPosNP);
@@ -140,6 +142,16 @@ bool INDI::Dome::updateProperties()
             defineSwitch(&DomeAutoSyncSP);
         }
 
+        if (capability.canPark)
+        {
+            defineSwitch(&ParkSP);
+            if (parkDataType != PARK_NONE)
+            {
+                defineNumber(&ParkPositionNP);
+                defineSwitch(&ParkOptionSP);
+            }
+        }
+
         defineNumber(&DomeMeasurementsNP);
     } else
     {
@@ -149,10 +161,10 @@ bool INDI::Dome::updateProperties()
             deleteProperty(DomeShutterSP.name);
 
         deleteProperty(DomeMotionSP.name);
-        if (capability.variableSpeed)
+        if (capability.hasVariableSpeed)
         {
             deleteProperty(DomeSpeedNP.name);
-            deleteProperty(DomeTimerNP.name);
+            //deleteProperty(DomeTimerNP.name);
         }
         if (capability.canRelMove)
             deleteProperty(DomeRelPosNP.name);
@@ -169,6 +181,16 @@ bool INDI::Dome::updateProperties()
             deleteProperty(DomeAutoSyncSP.name);
         }
 
+        if (capability.canPark)
+        {
+            deleteProperty(ParkSP.name);
+            if (parkDataType != PARK_NONE)
+            {
+                deleteProperty(ParkPositionNP.name);
+                deleteProperty(ParkOptionSP.name);
+            }
+        }
+
         deleteProperty(DomeMeasurementsNP.name);
     }
 
@@ -214,16 +236,24 @@ bool INDI::Dome::ISNewSwitch (const char *dev, const char *name, ISState *states
     {
         if (!strcmp(PresetGotoSP.name, name))
         {
+            if (domeState == DOME_PARKED)
+            {
+                DEBUGDEVICE(getDeviceName(), INDI::Logger::DBG_ERROR, "Dome is parked. Please unpark before issuing any motion commands.");
+                PresetGotoSP.s = IPS_ALERT;
+                IDSetSwitch(&PresetGotoSP, NULL);
+                return false;
+            }
+
             IUUpdateSwitch(&PresetGotoSP, states, names, n);
             int index = IUFindOnSwitchIndex(&PresetGotoSP);
-            int rc = MoveAbsDome(PresetN[index].value);
-            if (rc >= 0)
+            IPState rc = MoveAbs(PresetN[index].value);
+            if (rc == IPS_OK || rc == IPS_BUSY)
             {
                 PresetGotoSP.s = IPS_OK;
                 DEBUGF(INDI::Logger::DBG_SESSION, "Moving to Preset %d (%g degrees).", index+1, PresetN[index].value);
                 IDSetSwitch(&PresetGotoSP, NULL);
 
-                if (rc == 1)
+                if (rc == IPS_BUSY)
                 {
                     DomeAbsPosNP.s = IPS_BUSY;
                     IDSetNumber(&DomeAbsPosNP, NULL);
@@ -249,8 +279,8 @@ bool INDI::Dome::ISNewSwitch (const char *dev, const char *name, ISState *states
             else
             {
                 IDSetSwitch(&DomeAutoSyncSP,  "Dome is no longer synced to mount azimuth position.");
-                if (DomeAbsPosNP.s == IPS_BUSY || DomeRelPosNP.s == IPS_BUSY || DomeTimerNP.s == IPS_BUSY)
-                    AbortDome();
+                if (DomeAbsPosNP.s == IPS_BUSY || DomeRelPosNP.s == IPS_BUSY/* || DomeTimerNP.s == IPS_BUSY*/)
+                    Abort();
             }
 
             return true;
@@ -390,65 +420,104 @@ void INDI::Dome::processButton(const char * button_n, ISState state)
     if (state == ISS_OFF)
         return;
 
-    int rc=0;
     // Dome In
     if (!strcmp(button_n, "Dome CW"))
     {
-        if (capability.variableSpeed)
+        if (capability.canRelMove)
         {
-           rc = MoveDome(DOME_CW, DomeSpeedN[0].value, DomeTimerN[0].value);
-            if (rc == 0)
-                DomeTimerNP.s = IPS_OK;
-            else if (rc == 1)
-                DomeTimerNP.s = IPS_BUSY;
-            else
-                DomeTimerNP.s = IPS_ALERT;
-
-            IDSetNumber(&DomeTimerNP,NULL);
-        }
-        else if (capability.canRelMove)
-        {
-            rc=MoveRelDome(DOME_CW, DomeRelPosN[0].value);
-            if (rc == 0)
+            IPState rc= MoveRel(DomeRelPosN[0].value);
+            if (rc == IPS_OK)
             {
                DomeRelPosNP.s=IPS_OK;
                IDSetNumber(&DomeRelPosNP, "Dome moved %g degrees CW", DomeRelPosN[0].value);
                IDSetNumber(&DomeAbsPosNP, NULL);
             }
-            else if (rc == 1)
+            else if (rc == IPS_BUSY)
             {
                  DomeRelPosNP.s=IPS_BUSY;
                  IDSetNumber(&DomeAbsPosNP, "Dome is moving %g degrees CW...", DomeRelPosN[0].value);
             }
         }
+        else
+        {
+            if (DomeMotionSP.s == IPS_BUSY)
+            {
+                if (Move( DOME_CW, MOTION_STOP))
+                {
+                    IUResetSwitch(&DomeMotionSP);
+                    DomeMotionSP.s = IPS_IDLE;
+                    IDSetSwitch(&DomeMotionSP, NULL);
+                }
+                else
+                {
+                    DomeMotionSP.s = IPS_ALERT;
+                    IDSetSwitch(&DomeMotionSP, NULL);
+                }
+            }
+            else
+            {
+                if (Move( DOME_CW, MOTION_START))
+                {
+                    IUResetSwitch(&DomeMotionSP);
+                    DomeMotionS[DOME_CW].s = ISS_ON;
+                    DomeMotionSP.s = IPS_BUSY;
+                    IDSetSwitch(&DomeMotionSP, NULL);
+                }
+                else
+                {
+                    DomeMotionSP.s = IPS_ALERT;
+                    IDSetSwitch(&DomeMotionSP, NULL);
+                }
+            }
+        }
     }
     else if (!strcmp(button_n, "Dome CCW"))
     {
-        if (capability.variableSpeed)
+        if (capability.canRelMove)
         {
-           rc = MoveDome(DOME_CCW, DomeSpeedN[0].value, DomeTimerN[0].value);
-            if (rc == 0)
-                DomeTimerNP.s = IPS_OK;
-            else if (rc == 1)
-                DomeTimerNP.s = IPS_BUSY;
-            else
-                DomeTimerNP.s = IPS_ALERT;
-
-            IDSetNumber(&DomeTimerNP,NULL);
-        }
-        else if (capability.canRelMove)
-        {
-            rc=MoveRelDome(DOME_CCW, DomeRelPosN[0].value);
-            if (rc == 0)
+            IPState rc= MoveRel(DomeRelPosN[0].value*-1);
+            if (rc == IPS_OK)
             {
                DomeRelPosNP.s=IPS_OK;
-               IDSetNumber(&DomeRelPosNP, "Dome moved %g degrees CCW", DomeRelPosN[0].value);
+               IDSetNumber(&DomeRelPosNP, "Dome moved %g degrees CW", DomeRelPosN[0].value);
                IDSetNumber(&DomeAbsPosNP, NULL);
             }
-            else if (rc == 1)
+            else if (rc == IPS_BUSY)
             {
                  DomeRelPosNP.s=IPS_BUSY;
-                 IDSetNumber(&DomeAbsPosNP, "Dome is moving %g degrees CCW...", DomeRelPosN[0].value);
+                 IDSetNumber(&DomeAbsPosNP, "Dome is moving %g degrees CW...", DomeRelPosN[0].value);
+            }
+        }
+        else
+        {
+            if (DomeMotionSP.s == IPS_BUSY)
+            {
+                if (Move( DOME_CCW, MOTION_STOP))
+                {
+                    IUResetSwitch(&DomeMotionSP);
+                    DomeMotionSP.s = IPS_IDLE;
+                    IDSetSwitch(&DomeMotionSP, NULL);
+                }
+                else
+                {
+                    DomeMotionSP.s = IPS_ALERT;
+                    IDSetSwitch(&DomeMotionSP, NULL);
+                }
+            }
+            else
+            {
+                if (Move( DOME_CCW, MOTION_START))
+                {
+                    IUResetSwitch(&DomeMotionSP);
+                    DomeMotionS[DOME_CCW].s = ISS_ON;
+                    DomeMotionSP.s = IPS_BUSY;
+                    IDSetSwitch(&DomeMotionSP, NULL);
+                }
+                else
+                {
+                    DomeMotionSP.s = IPS_ALERT;
+                    IDSetSwitch(&DomeMotionSP, NULL);
+                }
             }
         }
     }
@@ -674,7 +743,7 @@ void INDI::Dome::UpdateAutoSync()
         if (fabs(targetAz - DomeAbsPosN[0].value) > DomeParamN[DOME_AUTOSYNC].value)
         {
             int ret = 0;
-            if ( (ret = MoveAbsDome(targetAz)) == 0)
+            if ( (ret = MoveAbs(targetAz)) == 0)
             {
                DomeAbsPosNP.s=IPS_OK;
                IDSetNumber(&DomeAbsPosNP, "Dome synced to position %g degrees.", targetAz);
@@ -692,5 +761,3 @@ void INDI::Dome::UpdateAutoSync()
        }
     }
 }
-
-
