@@ -29,7 +29,11 @@
 #include <unistd.h>
 #include <errno.h>
 
+#ifdef OSX_EMBEDED_MODE
+#include <libusb.h>
+#else
 #include <libusb-1.0/libusb.h>
+#endif
 
 #include "indibase.h"
 
