@@ -32,6 +32,7 @@
 #include <errno.h>
 #include <stdarg.h>
 #include <sys/param.h>
+#include <stdint.h>
 
 #if defined(BSD) && !defined(__GNU__)
 #include <IOKit/serial/ioss.h>
@@ -39,12 +40,11 @@
 #endif
 
 #include <config.h>
-
-#ifdef HAVE_NOVA_H
 #include <libnova.h>
-#endif
-
+#include <locale.h>
 #include "indicom.h"
+#include "indidevapi.h"
+
 #ifdef _WIN32
 #undef CX
 #undef CY
@@ -59,15 +59,10 @@
 
 #define MAXRBUF         2048
 
-#include "indidevapi.h"
-
 int tty_debug = 0;
 
-void getSexComponents(double value, int *d, int *m, int *s);
-
-int extractISOTime(char *timestr, struct ln_date *iso_date)
+int extractISOTime(const char *timestr, struct ln_date *iso_date)
 {
-  #ifdef HAVE_NOVA_H	
   struct tm utm;
 
   if (strptime(timestr, "%Y/%m/%dT%H:%M:%S", &utm))
@@ -81,7 +76,6 @@ int extractISOTime(char *timestr, struct ln_date *iso_date)
 	ln_get_date_from_tm(&utm, iso_date);
    	return (0);
   }
-  #endif
   
   return (-1);
 }
@@ -95,9 +89,7 @@ int extractISOTime(char *timestr, struct ln_date *iso_date)
  *	3600:	<w>:mm:ss
  *	600:	<w>:mm.m
  *	60:	<w>:mm
- * return number of characters written to out, not counting finaif (NOVA_FOUND)
-    include_directories(${NOVA_INCLUDE_DIR})
-endif (NOVA_FOUND)l '\0'.
+ * return number of characters written to out, not counting final '\0'.
  */
 int
 fs_sexa (char *out, double a, int w, int fracbase)
@@ -122,33 +114,33 @@ fs_sexa (char *out, double a, int w, int fracbase)
 
 	/* form the whole part; "negative 0" is a special case */
 	if (isneg && d == 0)
-	    out += sprintf (out, "%*s-0", w-2, "");
+        out += snprintf (out, MAXINDIFORMAT, "%*s-0", w-2, "");
 	else
-	    out += sprintf (out, "%*d", w, isneg ? -d : d);
+        out += snprintf (out, MAXINDIFORMAT, "%*d", w, isneg ? -d : d);
 
 	/* do the rest */
 	switch (fracbase) {
 	case 60:	/* dd:mm */
 	    m = f/(fracbase/60);
-	    out += sprintf (out, ":%02d", m);
+        out += snprintf (out, MAXINDIFORMAT, ":%02d", m);
 	    break;
 	case 600:	/* dd:mm.m */
-	    out += sprintf (out, ":%02d.%1d", f/10, f%10);
+        out += snprintf (out, MAXINDIFORMAT, ":%02d.%1d", f/10, f%10);
 	    break;
 	case 3600:	/* dd:mm:ss */
 	    m = f/(fracbase/60);
 	    s = f%(fracbase/60);
-	    out += sprintf (out, ":%02d:%02d", m, s);
+        out += snprintf (out, MAXINDIFORMAT, ":%02d:%02d", m, s);
 	    break;
 	case 36000:	/* dd:mm:ss.s*/
 	    m = f/(fracbase/60);
 	    s = f%(fracbase/60);
-	    out += sprintf (out, ":%02d:%02d.%1d", m, s/10, s%10);
+        out += snprintf (out, MAXINDIFORMAT, ":%02d:%02d.%1d", m, s/10, s%10);
 	    break;
 	case 360000:	/* dd:mm:ss.ss */
 	    m = f/(fracbase/60);
 	    s = f%(fracbase/60);
-	    out += sprintf (out, ":%02d:%02d.%02d", m, s/100, s%100);
+        out += snprintf (out, MAXINDIFORMAT, ":%02d:%02d.%02d", m, s/100, s%100);
 	    break;
 	default:
 	    printf ("fs_sexa: unknown fracbase: %d\n", fracbase);
@@ -168,6 +160,8 @@ f_scansexa (
 const char *str0,	/* input string */
 double *dp)		/* cracked value, if return 0 */
 {
+    setlocale(LC_NUMERIC,"C");
+
 	double a = 0, b = 0, c = 0;
 	char str[128];
 	char *neg;
@@ -180,7 +174,17 @@ double *dp)		/* cracked value, if return 0 */
 	neg = strchr(str, '-');
 	if (neg)
 	    *neg = ' ';
-	r = sscanf (str, "%lf%*[^0-9]%lf%*[^0-9]%lf", &a, &b, &c);
+    // JM 2015-09-04 Search for decimal point, and if found, process it
+    if (strchr(str, '.'))
+    {
+        r = sscanf (str, "%lf%*[^0-9]%lf", &a, &b);
+        c=0;
+    }
+    else
+        r = sscanf (str, "%lf%*[^0-9]%lf%*[^0-9]%lf", &a, &b, &c);
+
+    setlocale(LC_NUMERIC,"");
+
 	if (r < 1)
 	    return (-1);
 	*dp = a + b/60 + c/3600;
@@ -192,9 +196,9 @@ double *dp)		/* cracked value, if return 0 */
 void getSexComponents(double value, int *d, int *m, int *s)
 {
 
-  *d = (int) fabs(value);
-  *m = (int) ((fabs(value) - *d) * 60.0);
-  *s = (int) rint(((fabs(value) - *d) * 60.0 - *m) *60.0);
+  *d = (int32_t) fabs(value);
+  *m = (int32_t) ((fabs(value) - *d) * 60.0);
+  *s = (int32_t) rint(((fabs(value) - *d) * 60.0 - *m) *60.0);
 
   if (value < 0)
    *d *= -1;
@@ -219,7 +223,7 @@ numberFormat (char *buf, const char *format, double value)
             return (fs_sexa (buf, value, w-f, s));
         } else {
             /* normal printf format */
-            return (sprintf (buf, format, value));
+            return (snprintf (buf, MAXINDIFORMAT,  format, value));
         }
 }
 
@@ -294,17 +298,24 @@ int tty_write(int fd, const char * buf, int nbytes, int *nbytes_written)
 
   int bytes_w = 0;   
   *nbytes_written = 0;
-   
+
+  if (tty_debug)
+  {
+    int i=0;
+    for (i=0; i < nbytes; i++)
+         IDLog("%s: buffer[%d]=%#X (%c)\n", __FUNCTION__, i, (unsigned char) buf[i], buf[i]);
+  }
+
   while (nbytes > 0)
   {
     
-    bytes_w = write(fd, buf, nbytes);
+    bytes_w = write(fd, buf+(*nbytes_written), nbytes);
 
     if (bytes_w < 0)
      return TTY_WRITE_ERROR;
 
     *nbytes_written += bytes_w;
-    buf += bytes_w;
+    //buf += bytes_w;
     nbytes -= bytes_w;
   }
 
@@ -322,16 +333,23 @@ int tty_write_string(int fd, const char * buf, int *nbytes_written)
    
   nbytes = strlen(buf);
 
+  if (tty_debug)
+  {
+    int i=0;
+    for (i=0; i < nbytes; i++)
+         IDLog("%s: buffer[%d]=%#X (%c)\n", __FUNCTION__, i, (unsigned char) buf[i], buf[i]);
+  }
+
   while (nbytes > 0)
   {
     
-    bytes_w = write(fd, buf, nbytes);
+    bytes_w = write(fd, buf+(*nbytes_written), nbytes);
 
     if (bytes_w < 0)
      return TTY_WRITE_ERROR;
 
    *nbytes_written += bytes_w;
-    buf += bytes_w;
+    //buf += bytes_w;
     nbytes -= bytes_w;
   }
 
@@ -358,21 +376,22 @@ int tty_read(int fd, char *buf, int nbytes, int timeout, int *nbytes_read)
      if ( (err = tty_timeout(fd, timeout)) )
       return err;
 
-     bytesRead = read(fd, buf, ((unsigned) nbytes));
+     bytesRead = read(fd, buf+(*nbytes_read), ((uint32_t) nbytes));
 
      if (bytesRead < 0 )
       return TTY_READ_ERROR;
 
-     buf += bytesRead;
+     if (tty_debug)
+     {
+         IDLog("%d bytes read and %d bytes remaining...\n", bytesRead, nbytes-bytesRead);
+         int i=0;
+         for (i=*nbytes_read; i < (*nbytes_read+bytesRead); i++)
+            IDLog("%s: buffer[%d]=%#X (%c)\n", __FUNCTION__, i, (unsigned char) buf[i], buf[i]);
+     }
+
      *nbytes_read += bytesRead;
      nbytes -= bytesRead;
 
-     if (tty_debug)
-     {
-         int i=0;
-         for (i=0; i < (nbytes+*nbytes_read); i++)
-            IDLog("%s: buffer[%d]=%c\n", __FUNCTION__, i, buf[i]);
-     }
   }
 
   return TTY_OK;
@@ -387,6 +406,8 @@ int tty_read_section(int fd, char *buf, char stop_char, int timeout, int *nbytes
  int err = TTY_OK;
  *nbytes_read = 0;
 
+ uint8_t *read_char = 0;
+
  if (tty_debug)
      IDLog("%s: Request to read until stop char '%c' with %d timeout for fd %d\n", __FUNCTION__, stop_char, timeout, fd);
 
@@ -395,22 +416,19 @@ int tty_read_section(int fd, char *buf, char stop_char, int timeout, int *nbytes
          if ( (err = tty_timeout(fd, timeout)) )
 	   return err;
 
-         bytesRead = read(fd, buf, 1);
+         read_char = buf+*nbytes_read;
+         bytesRead = read(fd, read_char, 1);
 
          if (bytesRead < 0 )
             return TTY_READ_ERROR;
 
          if (tty_debug)
-                IDLog("%s: buffer[%d]=%c\n", __FUNCTION__, (*nbytes_read), buf[(*nbytes_read)]);
+                IDLog("%s: buffer[%d]=%#X (%c)\n", __FUNCTION__, (*nbytes_read), *read_char, *read_char);
 
-        if (bytesRead)
           (*nbytes_read)++;
 
-        if (*buf == stop_char)
+        if (*read_char == stop_char)
          return TTY_OK;
-
-        buf += bytesRead;
-
   }
 
   return TTY_TIME_OUT;
@@ -1215,3 +1233,59 @@ IUSaveText (IText *tp, const char *newtext)
         /* copy in fresh string */
         tp->text = strcpy (realloc (tp->text, strlen(newtext)+1), newtext);
 }
+
+double rangeHA(double r)
+{
+  double res = r;
+  while (res< -12.0) res+=24.0;
+  while (res>= 12.0) res-=24.0;
+  return res;
+}
+
+
+double range24(double r)
+{
+  double res = r;
+  while (res<0.0) res+=24.0;
+  while (res>24.0) res-=24.0;
+  return res;
+}
+
+double range360(double r)
+{
+  double res = r;
+  while (res<0.0) res+=360.0;
+  while (res>360.0) res-=360.0;
+  return res;
+}
+
+double rangeDec(double decdegrees)
+{
+  if ((decdegrees >= 270.0) && (decdegrees <= 360.0))
+    return (decdegrees - 360.0);
+  if ((decdegrees >= 180.0) && (decdegrees < 270.0))
+    return (180.0 - decdegrees);
+  if ((decdegrees >= 90.0) && (decdegrees < 180.0))
+    return (180.0 - decdegrees);
+  return decdegrees;
+}
+
+double get_local_sideral_time(double longitude)
+{
+    double SD = ln_get_apparent_sidereal_time(ln_get_julian_from_sys()) - (360.0 - longitude)/15.0;
+
+    return range24(SD);
+}
+
+double get_local_hour_angle(double sideral_time, double ra)
+{
+
+    double HA = sideral_time - ra;
+
+         if (HA > 12)
+             HA -= 12;
+         else if (HA < -12)
+             HA += 12;
+
+    return HA;
+}
